@@ -79,5 +79,11 @@ vmp.css=['vmp.css']
 vmp.js=['lib.js','utils.js','japi.js','cmp.js','jrp.js','base.js','main.js']
 jlibs_[vmp.name]=vmp
 
+mask=jlib()
+mask.name='mask'
+mask.dependencies=['img','vmp']
+mask.css=[]
+mask.js=['gadget.js','struct.js']
+jlibs_[mask.name]=mask
 
 
