@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 31/12/2024
+#Date last Update : 30/05/2025
 
 ##@package vmp
 #
@@ -65,6 +65,7 @@ from vmp_ import output_file_lines  as output_file_lines
 from vmp_ import input              as input
 from vmp_ import input_file         as input_file
 from vmp_ import input_file_s       as input_file_s
+from vmp_ import input_part_file    as input_part_file 
 from vmp_ import exit_ok            as exit_ok
 from vmp_ import exit_failure       as exit_failure
 from vmp_ import copy_file          as copy_file
@@ -103,6 +104,10 @@ from vmp_ import sigstr       as sigstr
 from vmp_ import sigcmp       as sigcmp
 from vmp_ import signal_wrap  as signal_wrap
 
+from vmp_ import errno as errno
+
+from vmp_ import strerror_wrap as strerror_wrap
+
 from vmp_ import thread       as thread
 
 from vmp_ import time         as time
