@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 02/01/2025
+   Date last update: 30/03/2025
  */
 
 #include "vmp_.h"
@@ -129,6 +129,8 @@ void vmp_init_fs(pylib::Module module)
     fs.def_("format_dirpath",vmp::fs::format_dirpath);
     fs.def_with_stub("union_path",stub_union_path());
     fs.def_("chmod_wrap",vmp::fs::chmod_wrap);
+    fs.def_("chown_wrap",vmp::fs::chown_wrap);
+    fs.def_("chown_user",vmp::fs::chown_user);
     fs.def_("mkdir_wrap",vmp::fs::mkdir_wrap);
     fs.def_("rmdir_wrap",vmp::fs::rmdir_wrap);
     fs.def_("chdir_wrap",vmp::fs::chdir_wrap);
