@@ -101,6 +101,25 @@ struct stub_localtime_set:public pylib::Member_def<vmp::time::Localtime>
     }
 };
 
+struct stub_localtime_next_cronizer:public pylib::Member_def<vmp::time::Localtime>
+{
+    pylib::Objref *def(vmp::time::Localtime *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            vmp::str crontab=args.get<vmp::str>(0);
+            return pylib::Converter<vmp_uint>(instance->next_cronizer(crontab));
+        }
+        else if(args.size() == 2)
+        {
+            vmp::str crontab=args.get<vmp::str>(0);
+            vmp_uint seconds=args.get<vmp_uint>(1);
+            return pylib::Converter<vmp_uint>(instance->next_cronizer(crontab,seconds));
+        }
+        return 0;
+    }
+};
+
 void vmp_init_time(pylib::Module module)
 {
     pylib::Module time=module.add_submodule("time");
@@ -115,7 +134,7 @@ void vmp_init_time(pylib::Module module)
     localtime.def_with_stub("set",stub_localtime_set());
     localtime.def_("get_year_days",&vmp::time::Localtime::get_year_days);
     localtime.def_("set_from_year_day",&vmp::time::Localtime::set_from_year_day);
-    localtime.def_("next_cronizer",&vmp::time::Localtime::next_cronizer);
+    localtime.def_with_stub("next_cronizer",stub_localtime_next_cronizer());
     localtime.def_("time",&vmp::time::Localtime::time);
     localtime.def_("sec",&vmp::time::Localtime::sec);
     localtime.def_("min",&vmp::time::Localtime::min);
