@@ -16,11 +16,35 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/05/2024
+   Date last update: 06/07/2025
  */
 
 #include "vmp_.h"
 
+struct stub_str_split:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+         vmp::str str;
+         vmp::str delimiter;
+         if(args.size() == 2)
+         {
+             str=args.get<vmp::str>(0);     
+             delimiter=args.get<vmp::str>(1);
+             return pylib::Converter<vmp::vector<vmp::str> >(vmp::unicode::str_split(str,delimiter));
+         }
+         else if(args.size() == 3)
+         {
+             str=args.get<vmp::str>(0);
+             delimiter=args.get<vmp::str>(1);
+             vmp_bool emptystr=args.get<vmp_bool>(2);
+             return pylib::Converter<vmp::vector<vmp::str> >(vmp::unicode::str_split(str,delimiter,emptystr));
+         }
+         else
+             return 0;
+    }
+};
+
 struct stub_str_regex:public pylib::Generic_def
 {
     pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
@@ -69,7 +93,8 @@ void vmp_init_unicode(pylib::Module module)
     // vmp/unicode.h
     unicode.def_("str_tolower",vmp::unicode::str_tolower);
     unicode.def_("str_toupper",vmp::unicode::str_toupper);
-    unicode.def_("str_split",vmp::unicode::str_split);
+    //unicode.def_with_stub("str_split",vmp::unicode::str_split);
+    unicode.def_with_stub("str_split",stub_str_split());
     unicode.def_("str_join",vmp::unicode::str_join);
     unicode.def_("byte_nbit",vmp::unicode::byte_nbit);
     unicode.def_("str_istype",vmp::unicode::str_istype);
@@ -80,6 +105,7 @@ void vmp_init_unicode(pylib::Module module)
     unicode.def_("str_toreal",vmp::unicode::str_toreal);
     unicode.def_("str_toreal_range",vmp::unicode::str_toreal_range);
     unicode.def_("xstr_tobytes",vmp::unicode::xstr_tobytes);
+    unicode.def_("xstr_tobytes_hm",vmp::unicode::xstr_tobytes_hm);
     unicode.def_("bytes_toxstr",vmp::unicode::bytes_toxstr);
     unicode.def_("bytes_toxstr_hm",vmp::unicode::bytes_toxstr_hm);
     unicode.def_("str_toxstr",vmp::unicode::str_toxstr);
