@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 20/03/2025
+#Date last Update : 28/05/2025
 
 import vmp
 import vmp_net
@@ -43,8 +43,11 @@ from vmp_crypto_  import sha384_bin as sha384_bin
 from vmp_crypto_  import sha512     as sha512
 from vmp_crypto_  import sha512_bin as sha512_bin
 
-from vmp_crypto_  import PKey as PKey
-from vmp_crypto_  import X509_Wrap as X509_Wrap
+from vmp_crypto_  import PKey                 as PKey
+from vmp_crypto_  import X509_Wrap            as X509_Wrap
+from vmp_crypto_  import X509_address_tourl   as X509_address_tourl
+from vmp_crypto_  import X509_address_fromurl as X509_address_fromurl
+from vmp_crypto_  import X509_isaddress       as X509_isaddress
 
 from vmp_crypto_  import Ctx  as Ctx
 from vmp_crypto_  import Ctx_Base_Tls_Client as Ctx_Base_Tls_Client
