@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 20/03/2025
+ * Date last update: 07/06/2025
  */
  
 #include "pylib.h"
@@ -68,7 +68,11 @@ void crypto_pkey(pylib::Module module);
     reset(),set_from_file(),parent(),version(),serial(),signature_info(),
     issuer(),validity_before(),validity_after(),subject(),pubkey(),
     id_issuer(),id_subject(),extensions(),signature_data(),fingerprint_sha1(),
-    fingerprint_sha256(),verify()
+    fingerprint_sha256(),address(),verify()
+*/
+/*!
+    Function c++ crypto/x509.h:<BR>
+    X509_address_tourl(),X509_address_fromurl(),X509_isaddress()
 */
 void crypto_x509(pylib::Module module);
 
