@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 11/01/2024
+#Date last Update : 17/01/2024
 
 import vmp
 import vmp_event_ as event
@@ -58,10 +58,11 @@ class App:
     vmp.init(data[0],data[1])
     self.pipe=data[2]
     self.appname=data[3]
-    self.args=args
-    vmp.signal_wrap(["sigint","sigusr1"],self.sigrecv)
+    vmp.input_=args
+    vmp.signal_wrap(['sigusr1','sigusr2','sigint','sigterm'],self.sigrecv)
     self.appui=None
     self.manager=None
+    self.closed_=False#true if it is closed remotely
     
   ##internal usage
   def lock_manager(self):
@@ -75,11 +76,12 @@ class App:
 
   ##internal usage
   def sigrecv(self,sig):
-    if vmp.sigcmp("sigint",sig):
+    if vmp.sigcmp("sigusr1",sig):
+      self.sigtrap()
+    elif vmp.sigcmp("sigusr2",sig):
+      self.closed_=True
       self.sigexit()
-    elif vmp.sigcmp("sigusr1",sig):
-      self.sigtrap() 
-  
+      
   ##internal usage in manager mode
   def read_msg(self,cell):
     self.lock_manager()
@@ -132,10 +134,11 @@ class App:
   def send(self,obj=None):
     msg=ProcMsg("msg",obj)
     self.lock_manager()
-    try:
-      self.pipe.send(msg)
-    except Exception as e:
-      self.manager.cell_close(cell,event.CELLRET_ERROR,str(e))
+    if not self.closed_:
+      try:
+        self.pipe.send(msg)
+      except Exception as e:
+        self.manager.cell_close(cell,event.CELLRET_ERROR,str(e))
     self.unlock_manager()
     
   ##Inserts the app into an event manager. Messages can be read along with other events in the loop manager<BR>
@@ -151,15 +154,16 @@ class App:
   #
   #@param error close errore("" no error)
   def exit(self,error=""):
-    if error == "":
-      msg=ProcMsg("close")
-    else:
-      msg=ProcMsg("close_err",error)
-    try:
-      self.pipe.send(msg)
-    except:
-      pass
-    self.pipe.close()
+    if not self.closed_:
+      if error == "":
+        msg=ProcMsg("close")
+      else:
+        msg=ProcMsg("close_err",error)
+      try:
+        self.pipe.send(msg)
+      except:
+        pass
+      self.pipe.close()
     vmp.exit_ok()
 
 ##Returns the processui associated with the Cell.(cell->ui() wrapper)<BR>
@@ -235,7 +239,7 @@ class UI:
   def pid(self,cell):
     return self.processui.pid(cell)
 
-  ##Return the Application name
+  ##Return the Application name<BR>
   #
   #@param cell event cell<BR>
   #@return application name
@@ -250,7 +254,7 @@ class UI:
 
   ##Send an object to the application<BR>
   #
-  #@param cell event cell
+  #@param cell event cell<BR>
   #@obj object to send
   def send(self,cell,obj):
     manager=cell.get_manager()
