@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/02/2024
+   Date last update: 24/10/2024
  */
 
 #include "event_.h"
@@ -96,6 +96,39 @@ struct stub_Manager_cell_close_wait:public pylib::Member_def<event::Manager>
     }
 };
 
+struct stub_Manager_cell_master:public pylib::Member_def<event::Manager>
+{
+    pylib::Objref *def(event::Manager *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            event::Cell *cell=args.get<event::Cell *>(0);
+            event::Cell *ret=instance->cell_master(cell);
+            if(ret == 0)
+                return pylib::retnone();
+            return pylib::Converter<event::Cell *>(ret,false); 
+        }
+        return 0;
+    }
+};
+
+struct stub_Manager_cell_searchsub:public pylib::Member_def<event::Manager>
+{
+    pylib::Objref *def(event::Manager *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 2)
+        {
+            event::Cell *cell=args.get<event::Cell *>(0);
+            vmp::str sid=args.get<vmp::str>(1);
+            event::Cell *ret=instance->cell_searchsub(cell,sid);
+            if(ret == 0)
+                return pylib::retnone();
+            return pylib::Converter<event::Cell *>(ret,false);
+        }
+        return 0;
+    }
+};
+
 void event_init_manager(pylib::Module module)
 {
     //event.h 
@@ -108,6 +141,8 @@ void event_init_manager(pylib::Module module)
     manager.def_("recovery_lock",&event::Manager::recovery_lock);
     manager.def_("cell_update",&event::Manager::cell_update);
     manager.def_("cell_timewait",&event::Manager::cell_timewait);
+    manager.def_("cell_get_timewait",&event::Manager::cell_get_timewait);
+    manager.def_("cell_get_timeout",&event::Manager::cell_timewait);
     manager.def_with_stub("cell_close",stub_Manager_cell_close());
     manager.def_("cell_close_ok_spec",&event::Manager::cell_close_ok_spec);
     manager.def_("cell_close_err_spec",&event::Manager::cell_close_err_spec);
@@ -115,8 +150,15 @@ void event_init_manager(pylib::Module module)
     manager.def_("time_now",&event::Manager::time_now);
     manager.def_("cell_alloc",&event::Manager::cell_alloc);
     manager.def_("cell_release",&event::Manager::cell_release);
+    manager.def_("cell_set_priority",&event::Manager::cell_set_priority);
+    manager.def_("cell_get_priority",&event::Manager::cell_get_priority);
     manager.def_("stop",&event::Manager::stop);
     manager.def_("loop",&event::Manager::loop);
+    manager.def_with_stub("cell_master",stub_Manager_cell_master());
+    manager.def_("cell_subid",&event::Manager::cell_subid);
+    manager.def_("cell_addsub",&event::Manager::cell_addsub);
+    manager.def_with_stub("cell_searchsub",stub_Manager_cell_searchsub());
+    manager.def_("cell_delsub",&event::Manager::cell_delsub);
 }
 
 struct stub_cell_close:public pylib::Member_def<event::Cell>
@@ -159,6 +201,7 @@ struct stub_cell_close_wait:public pylib::Member_def<event::Cell>
         return 0;
     }
 };
+
 struct stub_cell_ret:public pylib::Member_def<event::Cell>
 {
     pylib::Objref *def(event::Cell *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -245,7 +288,36 @@ struct stub_cell_remvar:public pylib::Member_def<event::Cell>
     }
 };
 
-VAMPIRIA_PYLIB_INIT(vmp_event_);
+struct stub_cell_master:public pylib::Member_def<event::Cell>
+{
+    pylib::Objref *def(event::Cell *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 0)
+        {
+            event::Cell *ret=instance->master();
+            if(ret == 0)
+                return pylib::retnone();
+            return pylib::Converter<event::Cell *>(ret,false); 
+        }
+        return 0;
+    }
+};
+
+struct stub_cell_searchsub:public pylib::Member_def<event::Cell>
+{
+    pylib::Objref *def(event::Cell *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            vmp::str sid=args.get<vmp::str>(0);
+            event::Cell *ret=instance->searchsub(sid);
+            if(ret == 0)
+                return pylib::retnone();
+            return pylib::Converter<event::Cell *>(ret,false);
+        }
+        return 0;
+    }
+};
 
 void event_init_cell(pylib::Module module)
 {
@@ -254,29 +326,43 @@ void event_init_cell(pylib::Module module)
     module.add_const<vmp_int>("CELLRET_SUCCESS",CELLRET_SUCCESS);
     module.add_const<vmp_int>("CELLRET_ERROR",CELLRET_ERROR);
     module.add_const<vmp_int>("CELLRET_TIMEOUT",CELLRET_TIMEOUT);
+    
+    //max event priority
+    module.add_const<vmp_uint>("MAX_CELL_PRIORITY",event::MAX_CELL_PRIORITY);
 
     //event.h
     pylib::Class<event::Cell> cell=module.class_no_constructor<event::Cell>("Cell");
     cell.def_("identity",&event::Cell::identity);
+    cell.def_("id",&event::Cell::id);
     cell.def_with_stub("close",stub_cell_close());
     cell.def_with_stub("close_wait",stub_cell_close_wait());
     cell.def_("close_err",&event::Cell::close_err);
     cell.def_("close_err_spec",&event::Cell::close_err_spec);
     cell.def_("alloc",&event::Cell::alloc);
     cell.def_("release",&event::Cell::release);
+    cell.def_("set_priority",&event::Cell::set_priority);
+    cell.def_("get_priority",&event::Cell::get_priority);
     cell.def_with_stub("ret",stub_cell_ret());
     cell.def_("closelevel",&event::Cell::closelevel);
     cell.def_("errcode",&event::Cell::errcode);
     cell.def_("str_error",&event::Cell::str_error);
     cell.def_("set_timewait",&event::Cell::set_timewait);
     cell.def_("get_timewait",&event::Cell::get_timewait);
+    cell.def_("get_timeout",&event::Cell::get_timeout);
     cell.def_("get_manager",&event::Cell::get_manager,false);
     cell.def_with_stub("setvar",stub_cell_setvar());
     cell.def_with_stub("getvar",stub_cell_getvar());
     cell.def_with_stub("remvar",stub_cell_remvar());
     cell.def_("all_keys",&event::Cell::all_keys);
+    cell.def_with_stub("master",stub_cell_master());
+    cell.def_("subid",&event::Cell::subid);
+    cell.def_("addsub",&event::Cell::addsub);
+    cell.def_with_stub("searchsub",stub_cell_searchsub());
+    cell.def_("delsub",&event::Cell::delsub);
 }
 
+VAMPIRIA_PYLIB_INIT(vmp_event_);
+
 void vampiria_pylib_init_module(pylib::Module init_module)
 {
     event_init_manager(init_module);
