@@ -97,7 +97,8 @@ void ProcessUI::close_event(event::Cell *cell)
     EventProcess *evt=cell->event<EventProcess>();
     if(evt->pid_ != -1)
     {
-        vmp::kill_wrap(evt->pid_,"sigint");
+        vmp::kill_wrap(evt->pid_,"sigusr2");
+        evt->pid_=-1;
         pylib::CArgs cargs(2);
         cargs.add<pylib::Objref *>(evt->proc_.ref());
         cargs.add<pylib::Objref *>(evt->pipe_.ref());
@@ -341,7 +342,8 @@ struct stub_processui_trap:public pylib::Member_def<ProcessUI>
             event::Manager *manager=instance->manager();
             manager->lock();
             EventProcess *evt=cell->event<EventProcess>();
-            vmp::kill_wrap(evt->pid_,"sigusr1");
+            if(evt->pid_ != -1)
+                vmp::kill_wrap(evt->pid_,"sigusr1");
             manager->unlock();
             return pylib::none();
         }
