@@ -191,6 +191,7 @@ void PyCroniterUI::free_ref(event::Cell *cell)
     cevent->crontab_="";
     cevent->event_=0;
     cevent->badnext_=false;
+    cevent->seconds_=0;
     cevent->evt_timer_free();
     pycref_.free(cevent);
 }
@@ -265,7 +266,7 @@ struct stub_CroniterUI_new_croniter:public pylib::Member_def<PyCroniterUI>
         event::EVTCB clevent;
         vmp_bool active=true;
         manager->lock();
-        if(args.size() == 4 || args.size() == 5)
+        if(args.size() == 4 || args.size() == 5 || args.size() == 6)
         {
             PyCroniterRef *cevent;
             try
@@ -279,8 +280,12 @@ struct stub_CroniterUI_new_croniter:public pylib::Member_def<PyCroniterUI>
                     clevent=0;
                 else 
                     clevent=croniter_close;
-                if(args.size() == 5)
+                if(args.size() >= 5)
                     active=args.get<vmp_bool>(4);
+                if(args.size() == 6)
+                    cevent->seconds_=args.get<vmp_uint>(5);
+                else
+                    cevent->seconds_=0; 
                 cevent->next_.set();
                 cevent->evt_croniter_next();
                 cell=cevent->evt_timer_new(instance,0,croniter_evt,clevent);
