@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 07/01/2025
+ * Date last update: 01/07/2025
  */
  
 #include "jrp_.h"
@@ -207,6 +207,19 @@ struct stub_JrpUI_set_p2p_server_event:public pylib::Member_def<PyJrpUI>
     }
 };
 
+struct stub_JrpUI_jrpcommon:public pylib::Member_def<PyJrpUI>
+{
+    pylib::Objref *def(PyJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 0)
+        {
+            PyJrpCommon *jrpcommon=(PyJrpCommon *)instance->jrpcommon();
+            return pylib::Converter<PyJrpCommon *>(jrpcommon,false);    
+        }
+        return 0;
+    }
+};
+
 struct stub_JrpUI_new_client:public pylib::Member_def<PyJrpUI>
 {
     pylib::Objref *def(PyJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -496,6 +509,18 @@ struct stub_WssJrpUI_new_listen:public pylib::Member_def<PyWssJrpUI>
     }
 };
 
+struct stub_WssJrpUI_jrpcommon:public pylib::Member_def<PyWssJrpUI>
+{
+    pylib::Objref *def(PyWssJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 0)
+        {
+            PyJrpCommon *jrpcommon=(PyJrpCommon *)instance->jrpcommon();
+            return pylib::Converter<PyJrpCommon *>(jrpcommon,false);    
+        }
+        return 0;
+    }
+};
 struct stub_WssJrpUI_connect_search:public pylib::Member_def<PyWssJrpUI>
 {
     pylib::Objref *def(PyWssJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -562,7 +587,12 @@ void jrp_init(pylib::Module module)
     module.add_const<vmp_int>("status_kill_notcomplete",jrp::status_kill_notcomplete);
     module.add_const<vmp_int>("status_forward_denied",jrp::status_forward_denied);
     module.add_const<vmp_int>("status_request_overflow",jrp::status_request_overflow);
-    
+    module.add_const<vmp_int>("status_resource_notfound",jrp::status_resource_notfound);
+    module.add_const<vmp_int>("status_request_timeout",jrp::status_request_timeout);
+    module.add_const<vmp_int>("status_managed_timeout",jrp::status_managed_timeout);
+    module.add_const<vmp_int>("status_accesspeerdenied",jrp::status_accesspeerdenied);
+    module.add_const<vmp_int>("status_internal",jrp::status_internal);
+    module.add_const<vmp_int>("status_resource_killed",jrp::status_resource_killed);
     module.add_const<vmp_index>("min_permits",jrp::min_permits);
     module.add_const<vmp_index>("max_permits",jrp::max_permits);
     
@@ -581,7 +611,7 @@ void jrp_init(pylib::Module module)
     jrpui.def_("proxychain",&PyJrpUI::proxychain,false);
     jrpui.def_("connection_type",&PyJrpUI::connection_type);
     jrpui.def_("connection_strtype",&PyJrpUI::connection_strtype);
-    jrpui.def_("jrpcommon",&PyJrpUI::jrpcommon,false);
+    jrpui.def_with_stub("jrpcommon",stub_JrpUI_jrpcommon());
     jrpui.def_("ctx",&PyJrpUI::ctx,false);
     jrpui.def_("logger",&PyJrpUI::logger,false);
     jrpui.def_with_stub("connect_search",stub_JrpUI_connect_search());
@@ -625,7 +655,7 @@ void jrp_init(pylib::Module module)
     wssjrpui.def_("peeraddr",&PyWssJrpUI::peeraddr,false);
     wssjrpui.def_("connection_type",&PyWssJrpUI::connection_type);
     wssjrpui.def_("connection_strtype",&PyWssJrpUI::connection_strtype);
-    wssjrpui.def_("jrpcommon",&PyWssJrpUI::jrpcommon,false);
+    wssjrpui.def_with_stub("jrpcommon",stub_WssJrpUI_jrpcommon());
     wssjrpui.def_("ctx",&PyWssJrpUI::ctx,false);
     wssjrpui.def_("logger",&PyWssJrpUI::logger,false);
     wssjrpui.def_with_stub("connect_search",stub_WssJrpUI_connect_search());
@@ -645,6 +675,7 @@ void vampiria_pylib_init_module(pylib::Module init_module)
     pylib::Module misc=init_module.add_submodule("misc");
     jrp_misc_status(misc);
     jrp_misc_utils(misc);
+    jrp_misc_onion(misc);
 }
 
  
