@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 30/11/2024
+ * Date last update: 31/03/2025
  */
  
 #include "jrp_.h"
@@ -111,6 +111,25 @@ struct stub_jrpreq_request_oper:public pylib::Member_def<jrp::JrpReq>
     }
 };
 
+struct stub_jrpreq_set_timeout:public pylib::Member_def<jrp::JrpReq>
+{
+    pylib::Objref *def(jrp::JrpReq *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 0)
+        {
+            instance->set_timeout();
+            return pylib::retnone();
+        }
+        else if(args.size() == 1)
+        {
+            vmp::time::Time timeout=args.get<vmp::time::Time>(0);
+            instance->set_timeout(timeout);
+            return pylib::retnone();
+        } 
+        return 0;
+    }
+};
+
 struct stub_jrpreq_push_oper:public pylib::Member_def<jrp::JrpReq>
 {
     pylib::Objref *def(jrp::JrpReq *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -153,6 +172,7 @@ void jrp_jrpreq(pylib::Module module)
     jrpreq.def_("alloc",&jrp::JrpReq::alloc);
     jrpreq.def_("release_internal",&jrp::JrpReq::release_internal);
     jrpreq.def_("release",&jrp::JrpReq::release);
+    jrpreq.def_with_stub("set_timeout",stub_jrpreq_set_timeout());
     jrpreq.def_with_stub("push",stub_jrpreq_push());
     jrpreq.def_with_stub("response",stub_jrpreq_response());
     jrpreq.def_("kill",&jrp::JrpReq::kill);
