@@ -16,7 +16,8 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/01/2025*/
+   Date last update: 26/04/2025
+*/
 
 #include "jrp_.h"
 
@@ -165,8 +166,30 @@ struct stub_misc_ConnectStatus_register_common:public pylib::Member_def<jrp::mis
     }
 };
 
+struct stub_misc_Logs_register_common:public pylib::Member_def<jrp::misc::Logs>
+{
+    pylib::Objref *def(jrp::misc::Logs *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            jrp::JrpCommon *common=(jrp::JrpCommon *)args.get<PyJrpCommon *>(0);
+            instance->register_common(common);
+            return pylib::retnone();
+        }
+        else if(args.size() == 2)
+        {
+            jrp::JrpCommon *common=(jrp::JrpCommon *)args.get<PyJrpCommon *>(0);
+            vmp::str permits=args.get<vmp::str>(1);
+            instance->register_common(common,permits);
+            return pylib::retnone();
+        }
+        return 0;
+    }
+};
 void jrp_misc_utils(pylib::Module module)
 {
+    module.def_("japi",jrp::misc::japi);
+    
     pylib::Class<jrp::misc::Passwd> passwd=module.class_with_constructor<jrp::misc::Passwd>("Passwd",Misc_Passwd_stub_Constructor());
     passwd.def_with_stub("register_common",stub_misc_passwd_register_common());
     passwd.def_("management",&jrp::misc::Passwd::management);
@@ -182,5 +205,10 @@ void jrp_misc_utils(pylib::Module module)
     pylib::Class<jrp::misc::ConnectStatus> connectstatus=module.class_with_constructor<jrp::misc::ConnectStatus>("ConnectStatus",Misc_ConnectStatus_stub_Constructor());
     connectstatus.def_with_stub("register_common",stub_misc_ConnectStatus_register_common());
     connectstatus.def_("management",&jrp::misc::ConnectStatus::management);
+
+    pylib::Class<jrp::misc::Logs> logs=module.class_<jrp::misc::Logs>("Logs");
+    logs.def_("set_logdir",&jrp::misc::Logs::set_logdir);
+    logs.def_with_stub("register_common",stub_misc_Logs_register_common());
+    logs.def_("management",&jrp::misc::Logs::management);
 }
 
