@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 22/11/2024
+#Date last Update : 21/03/2025
 
 from vmp_json_  import Json    as Json
 from vmp_json_  import JsonObj as JsonObj
@@ -56,4 +56,8 @@ from vmp_json_  import japi_peerdel       as japi_peerdel
 from vmp_json_  import japi_connectlist   as japi_connectlist
 from vmp_json_  import japi_connectinfo   as japi_connectinfo
 from vmp_json_  import japi_connectclose  as japi_connectclose
+from vmp_json_  import japi_logs          as japi_logs
+from vmp_json_  import japi_logfiles      as japi_logfiles
+from vmp_json_  import japi_logread       as japi_logread
+from vmp_json_  import japi_logview       as japi_logview 
 
