@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 20/03/2025
+ * Date last update: 21/03/2025
  */
 
 #include "json_.h"
@@ -372,5 +372,9 @@ void json_japi(pylib::Module module)
     module.def_("japi_connectlist",json::japi_connectlist);
     module.def_with_stub("japi_connectinfo",stub_japi_connectinfo());
     module.def_("japi_connectclose",json::japi_connectclose);
+    module.def_("japi_logs",json::japi_logs);
+    module.def_("japi_logfiles",json::japi_logfiles);
+    module.def_("japi_logread",json::japi_logread);
+    module.def_("japi_logview",json::japi_logview);
 }
 
