@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 10/04/2022
+ * Date last update: 04/12/2024
  */
 
 #include "json_.h"
@@ -44,29 +44,6 @@ struct stub_JData_new_list:public pylib::Member_def<json::JData>
     }
 };
 
-struct stub_JData_set_list:public pylib::Member_def<json::JData>
-{
-    pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
-    {
-        if(args.size() == 2)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JList *list=args.get<json::JList *>(1);
-            instance->set_list(label,list);
-            return pylib::retnone();
-        }
-        else if(args.size() == 3)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JList *list=args.get<json::JList *>(1);
-            vmp::str jtype=args.get<vmp::str>(2);
-            instance->set_list(label,list,jtype);
-            return pylib::retnone();
-        }
-        return 0;
-    }
-};
-
 struct stub_JData_get_list:public pylib::Member_def<json::JData>
 {
     pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -113,29 +90,6 @@ struct stub_JData_new_table:public pylib::Member_def<json::JData>
     }
 };
 
-struct stub_JData_set_table:public pylib::Member_def<json::JData>
-{
-    pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
-    {
-        if(args.size() == 2)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JTable *table=args.get<json::JTable *>(1);
-            instance->set_table(label,table);
-            return pylib::retnone();
-        }
-        else if(args.size() == 3)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JTable *table=args.get<json::JTable *>(1);
-            vmp::str jtype=args.get<vmp::str>(2);
-            instance->set_table(label,table,jtype);
-            return pylib::retnone();
-        }
-        return 0;
-    }
-};
-
 struct stub_JData_get_table:public pylib::Member_def<json::JData>
 {
     pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -211,52 +165,6 @@ struct stub_JData_set_custom:public pylib::Member_def<json::JData>
     }
 };
 
-struct stub_JData_set_subtype:public pylib::Member_def<json::JData>
-{
-    pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
-    {
-        if(args.size() == 2)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
-            instance->set_subtype(label,jdata);
-            return pylib::retnone();                      
-        }
-        else if(args.size() == 3)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
-            vmp::str jtype=args.get<vmp::str>(2);
-            instance->set_subtype(label,jdata,jtype);
-            return pylib::retnone(); 
-        }
-        return 0;
-    }
-};
-
-struct stub_JData_get_subtype:public pylib::Member_def<json::JData>
-{
-    pylib::Objref *def(json::JData *instance,pylib::Args &args,pylib::KwArgs &kwargs)
-    {
-        if(args.size() == 2)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
-            instance->get_subtype(label,jdata);
-            return pylib::retnone();                      
-        }
-        else if(args.size() == 3)
-        {
-            vmp::str label=args.get<vmp::str>(0);
-            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
-            vmp::str jtype=args.get<vmp::str>(2);
-            instance->get_subtype(label,jdata,jtype);
-            return pylib::retnone(); 
-        }
-        return 0;
-    }
-};
-
 void json_jdata(pylib::Module module)
 {
     pylib::Class<json::JData> jdata=module.class_<json::JData>("JData");
@@ -279,10 +187,10 @@ void json_jdata(pylib::Module module)
     jdata.def_("set_bool",&json::JData::set_bool);
     jdata.def_("get_bool",&json::JData::get_bool);
     jdata.def_with_stub("new_list",stub_JData_new_list());
-    jdata.def_with_stub("set_list",stub_JData_set_list());
+    jdata.def_("set_list",&json::JData::set_list);
     jdata.def_with_stub("get_list",stub_JData_get_list());
     jdata.def_with_stub("new_table",stub_JData_new_table());
-    jdata.def_with_stub("set_table",stub_JData_set_table());
+    jdata.def_("set_table",&json::JData::set_table);
     jdata.def_with_stub("get_table",stub_JData_get_table());
     jdata.def_("set_args",&json::JData::set_args);
     jdata.def_("get_args",&json::JData::get_args);
@@ -290,8 +198,8 @@ void json_jdata(pylib::Module module)
     jdata.def_with_stub("get_vars",stub_JData_get_vars());
     jdata.def_with_stub("set_custom",stub_JData_set_custom());
     jdata.def_("get_custom",&json::JData::get_custom);
-    jdata.def_with_stub("set_subtype",stub_JData_set_subtype());
-    jdata.def_with_stub("get_subtype",stub_JData_get_subtype());
+    jdata.def_("set_subtype",&json::JData::set_subtype);
+    jdata.def_("get_subtype",&json::JData::get_subtype);
     jdata.def_("set_buf",&json::JData::set_buf);
     jdata.def_("get_buf",&json::JData::get_buf);
     jdata.def_("set_netaddress",&json::JData::set_netaddress);
