@@ -143,7 +143,5 @@ void vampiria_pylib_init_module(pylib::Module init_module)
     json_jlist(init_module);
     json_jtable(init_module);
     json_japi(init_module);
-    json_jrp(init_module);
-    json_status(init_module);
 }
 
