@@ -16,15 +16,20 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 25/10/2024
+#Date last Update : 08/04/2025
 
 ##@package vmp_net
 #
 # Wrapper c++ namespace vampiria::net
 
 from vmp_net_ import is_ipv4_raw           as is_ipv4_raw
+from vmp_net_ import ipv4_subnet           as ipv4_subnet
 from vmp_net_ import ipv4_expand           as ipv4_expand
+from vmp_net_ import ipv4_to_net           as ipv4_to_net
 from vmp_net_ import is_ipv6_raw           as is_ipv6_raw
+from vmp_net_ import ipv6_subnet           as ipv6_subnet
+from vmp_net_ import ipv6_to_net           as ipv6_to_net
+from vmp_net_ import ipv6_addr_contracted  as ipv6_addr_contracted
 from vmp_net_ import is_ip_raw             as is_ip_raw
 from vmp_net_ import ip_to_buf             as ip_to_buf
 from vmp_net_ import ipv4_from_buf         as ipv4_from_buf
