@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 05/11/2024
+   Date last update: 08/04/2025
  */
 
 #include "net_.h"
@@ -93,8 +93,13 @@ void net_init(pylib::Module module)
 {
     //net/address.h
     module.def_("is_ipv4_raw",net::is_ipv4_raw);
+    module.def_("ipv4_subnet",net::ipv4_subnet);
     module.def_("ipv4_expand",net::ipv4_expand);
+    module.def_("ipv4_to_net",net::ipv4_to_net);
     module.def_("is_ipv6_raw",net::is_ipv6_raw);
+    module.def_("ipv6_subnet",net::ipv6_subnet);
+    module.def_("ipv6_to_net",net::ipv6_to_net);
+    module.def_("ipv6_addr_contracted",net::ipv6_addr_contracted);
     module.def_("is_ip_raw",net::is_ip_raw);
     module.def_("ip_to_buf",net::ip_to_buf);
     module.def_("ipv4_from_buf",net::ipv4_from_buf);
