@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 28/10/2024
+   Date last update: 08/04/2025
  */
 
 #include "vmp.h"
@@ -29,8 +29,11 @@
 
 //!Python wrapper of the c++ namespace vampiria::net in vmp_net.(see c++ doc)
 /*!
-    Function c++ in net/address.h:<BR>is_ipv4_raw(),ipv4_expand(),is_ipv6_raw(),is_ip_raw(),ip_to_buf(),ipv4_from_buf(),ipv6_from_buf(),
-    is_macaddress_raw(),macaddress_to_buf(),macaddress_from_buf()
+    Function c++ in net/address.h:<BR>
+    is_ipv4_raw(),ipv4_subnet(),ipv4_expand(),ipv4_to_net(),is_ipv6_raw(),
+    ipv6_subnet(),ipv6_to_net(),ipv6_addr_contracted(),is_ip_raw(),
+    ip_to_buf(),ipv4_from_buf(),ipv6_from_buf(),is_macaddress_raw(),
+    macaddress_to_buf(),macaddress_from_buf()
 */
 /*!
     Const c++ in net/connection.h:<BR>CONN_NONE,CONN_UDP4,CONN_UDP6,CONN_UDPCONNECT,CONN_UDPPROXY
