@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 01/03/2024
+   Date last update: 24/10/2024
  */
 
 #include "net_.h"
@@ -160,9 +160,9 @@ struct stub_UdpUI_new_client:public pylib::Member_def<PyUdpUI>
         else if(args.size() == 2)
         {
             net::Address *peer=args.get<net::Address *>(0);
-            net::ProxyInfo *proxy=0;
+            net::ProxyChain *proxy=0;
             if(!args.is_none(1))
-                proxy=args.get<net::ProxyInfo *>(1);
+                proxy=args.get<net::ProxyChain *>(1);
             return pylib::Converter<event::Cell *>(instance->new_client(peer,proxy),false);
         }
         return 0;
@@ -187,8 +187,9 @@ void net_init_udpui(pylib::Module module)
     udpui.def_("maxpsize",&PyUdpUI::maxpsize);
     udpui.def_("localaddr",&PyUdpUI::localaddr,false);
     udpui.def_("peeraddr",&PyUdpUI::peeraddr,false);
-    udpui.def_("proxyinfo",&PyUdpUI::proxyinfo,false);
+    udpui.def_("proxychain",&PyUdpUI::proxychain,false);
     udpui.def_("connection_type",&PyUdpUI::connection_type);
     udpui.def_("connection_strtype",&PyUdpUI::connection_strtype);
+    udpui.def_("lastfrag",&PyUdpUI::lastfrag);
 }
 
