@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 05/03/2020
+   Date last update: 01/12/2022
  */
 
 #include "vmp.h"
@@ -46,7 +46,7 @@ void xml_init(pylib::Module module);
      get_parent(),get_child(),get_child_number(),parser_error()
 */
 /*!
-     Parser class in xml.h(DomParser virtual):<BR>Constructor Parser()<BR>
+     Parser class in xml.h(DomParser virtual):<BR>Constructor Parser(objtypedefault) wrapper Parser() constructor in __init__.py<BR>
      Parser member function add_tag(name,objtype)<BR>
      Adds a python type object. The object must come from the vmp_net.Tag class. The name parameter is the name associated with the tag type, the objtype parameter the typed object.<BR><BR>
      Parser member function list:<BR>get_root(),build(),build_from_str(),destroy(),reset()
