@@ -168,9 +168,7 @@ SSL_CTX *Ctx_Peer::init()
     
     crypto::X509_Wrap scert;
     scert.set(SSL_CTX_get0_certificate(ctx));
-    vmp::Buf buf;
-    scert.fingerprint_sha256(&buf);
-    fingerprint_=buf.read_xstr_hm(buf.size(),":");
+    fingerprint_=scert.address();
     if(cert_create)
         vmp::output_file(info_,true,"Fingerprint: %s\nSubject: %s\n",fingerprint().c_str(),subject().c_str());
     return ctx;
@@ -281,9 +279,7 @@ vmp_uint Ctx_Peer::verify_peer(crypto::Ssl *ssl,crypto::Ctx_Peer_Acl *ret)
             if(!cout.verify(&kout))
                  vmp::except_s("");
             vmp::str subject=cout.subject();
-            vmp::Buf buf;
-            cout.fingerprint_sha256(&buf);
-            vmp::str fingerprint=buf.read_xstr_hm(buf.size(),":");
+            vmp::str fingerprint=cout.address();
             vmp_uint retvalue=verify_acl_peer(fingerprint,subject);
             if(ret != 0)
             {
