@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 21/01/2025
+ * Date last update: 30/06/2025
  */
 
 #include "crypto.h"
@@ -260,12 +260,10 @@ void EventSsl::evt_ssl_reset(vmp_bool init)
     common_=0;
     linktype_=crypto::LINK_NORMAL;
     framing_.reset();
-    framingcode_=0;
     timeping_=0;
     if(!init)
         ssl_.reset();
     sslsend_=crypto::ssl_sslsend;
-    shutdownlevel_="";
 }
 
 void EventSsl::evt_ssl_ctimeout(vmp_bool active)
@@ -422,21 +420,17 @@ void EventSsl::evt_ssl_framing_bin(vmp::Buf *buf)
 
 void EventSsl::evt_ssl_framing_close(vmp_uint code,vmp::str msg)
 {
-    if(linktype_ == crypto::LINK_WSFRAMING)
-    {
-        event::Manager *manager=cell_->get_manager();
-        framingcode_=code;
-        if(code == packet::websocket::WebSocketCode_Normal)
-            manager->cell_close_ok_spec(cell_,"crypto::EventSslFraming");
-        else
-        {
-            if(msg == "")
-                manager->cell_close_err_spec(cell_,"crypto::EventSslFraming",framingcode_,packet::websocket::WebSocketCode_reason(framingcode_));
-            else
-                manager->cell_close_err_spec(cell_,"crypto::EventSslFraming",framingcode_,msg);
-                
-        }
-    }
+    event::Manager *manager=cell_->get_manager();
+    if(msg == "")
+        msg=packet::websocket::WebSocketCode_reason(code);
+    vmp::Buf *buf=framing_.frame_close(code,msg);
+    evt_connection_send(buf);
+    framing_.free_buf(buf);
+    ssl_.shutdown();
+    if(code == packet::websocket::WebSocketCode_Normal)
+        manager->cell_close_ok_spec(cell_,"crypto::EventSslFraming");
+    else
+        manager->cell_close_err_spec(cell_,"crypto::EventSslFraming",code,msg);
 }
 
 void EventSsl::evt_ssl_sub_active(crypto::EventSslSub *sub)
@@ -477,36 +471,6 @@ void EventSsl::evt_ssl_close()
 {
     if(sub_ != 0)
         sub_->evtsub_ssl_close();
-    try
-    {
-        if(linktype_ == crypto::LINK_WSFRAMING)
-        {
-             if(cell_->closelevel_ == "")
-                 cell_->closelevel_="crypto::EventSslFraming"; 
-             if(cell_->closelevel_ == "crypto::EventSslFraming")
-             {
-                 if(framingcode_ == 0)
-                 {
-                     if(cell_->ret_ == event::SUCCESS)
-                         framingcode_=packet::websocket::WebSocketCode_Normal;   
-                     else if(cell_->ret_ == event::ERROR)
-                     {
-                         framingcode_=packet::websocket::WebSocketCode_Unexpected;
-                         cell_->errcode_=framingcode_;
-                     }
-                 }
-                 if(framingcode_ != 0)
-                 {
-                     vmp::Buf *buf=framing_.frame_close(framingcode_,cell_->err_);
-                     evt_connection_send(buf,true);
-                     framing_.free_buf(buf);
-                 }
-             }
-        }
-    }
-    catch(vmp::exception &x)
-    {
-    }
     evt_connection_close();
 }
        
@@ -523,13 +487,17 @@ void ssl_shutdown(event::Cell *cell,vmp::str closelevel)
     event::Manager *manager=cell->get_manager();
     manager->lock();
     crypto::EventSsl *ssl=cell->event<crypto::EventSsl>();
-    ssl->shutdownlevel_=closelevel;
-    vmp_int ret=ssl->ssl_.shutdown();
-    if(ret == 0)
-        manager->cell_close_ok_spec(cell,ssl->shutdownlevel_);
-    else if(ret == -1)
-        manager->cell_close_err_spec(cell,ssl->shutdownlevel_,ssl->ssl_.get_errno(),crypto::err_string());
-    manager->unlock();    
+    if(ssl->linktype_ == crypto::LINK_WSFRAMING)
+        ssl->evt_ssl_framing_close();
+    else
+    {
+        vmp_int ret=ssl->ssl_.shutdown();
+        if(ret == 0)
+            manager->cell_close_ok_spec(cell,closelevel);
+        else if(ret == -1)
+            manager->cell_close_err_spec(cell,closelevel,ssl->ssl_.get_errno(),crypto::err_string());
+    }
+    manager->unlock();
 }
 
 }}
