@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 21/01/2025
+   Date last update: 30/06/2025
  */
  
 #ifndef VAMPIRIA_CRYPTO_EVENTSSL_H
@@ -289,10 +289,8 @@ class EventSsl:public net::EventConnection
         crypto::SslCommon *common_;/*!<Shared object for all events*/
         crypto::Ssl ssl_;/*!<Ssl connection associated*/
         vmp::time::Time ctimeout_;/*!<Connection timeout*/
-        vmp::str shutdownlevel_;/*!<Internal usage*/
         
         packet::websocket::FramingHelper framing_;/*!<Framing protocol helper*/
-        vmp_uint framingcode_;/*!<Frame close code,used in evt_wss_frame_close()*/
         vmp_int linktype_;/*!<The type of communication used for the link*/
         vmp::time::Time timeping_;/*!<Time when the ping was sent*/
         
@@ -381,6 +379,7 @@ class EventSsl:public net::EventConnection
         */
         void evt_ssl_framing_bin(vmp::Buf *buf);
         
+        
         //! Send a connection closure for framing protocol
         /*!
             @param code websocket framing code
