@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 14/01/2023
+ * Date last update: 22/10/2024
  */
 
 #ifndef VAMPIRIA_EVENT_LIB_H
@@ -30,12 +30,16 @@ class Manager;
 class UI;
 
 typedef void (*EVTCB)(event::Cell *cell);/*!< Simplex type callback*/
+typedef void (*EVTCBCLOSE)(event::Cell *cell,vmp_int retcode,vmp::str retmsg);/*!< Close event callback*/
 typedef void (*EVTCBBUF)(event::Cell *cell,vmp::Buf *buf);/*<!Event Buffer type callback*/
 typedef void (*EVTCBSTR)(event::Cell *cell,vmp::str data); /*!< Event string type callback*/
 
 //!Empty EVTCB callback
 void empty_ev(event::Cell *cell);
 
+//!Empty EVTCB callback
+void empty_close_ev(event::Cell *cell,vmp_int retcode,vmp::str retmsg);
+
 //!Empty EVTCBBUF callback
 void empty_buf_ev(event::Cell *cell,vmp::Buf *buf);
 
@@ -45,22 +49,25 @@ void empty_str_ev(event::Cell *cell,vmp::str data);
 //!Base class event
 class Event
 {
+    protected:
+        vmp_int priority_; /*!<priority of the event execution,Initial value when the event is created*/
     public:
-       //!A Constructor
-       Event();
+        //!A Constructor
+        Event();
 
-       //!A destructor
-       ~Event();
+        //!A destructor
+        ~Event();
 
-       vmp_bool active_;/*!event is active?*/
-       vmp_int priority_; /*!<priority of the event execution*/
-
-       void set_priority(vmp_int priority=0);
-
-       vmp_int fd_;/*< Filedescriptor associated*/
-
-       event::Cell *cell_;/*<Cell associated*/
+        vmp_bool active_;/*!<event is active?*/
+        
+        vmp_int fd_;/*!< Filedescriptor associated*/
 
+        event::Cell *cell_;/*!<Cell associated*/
+       
+        vmp::Table<vmp::str,event::Cell *> evtsubs_;/*!<Associated sub-events.If the main event ends, its sottoevents will also be finished*/
+        event::Cell *master_;/*!<master event associated,When the master event is closed, it is set to 0 */
+        vmp::str sid_;/*!Subevent id*/
+        
        //!Create a new event base
        /*!
            @param  ui user interface (see Class UI)
@@ -77,10 +84,10 @@ class Event
            @sa active
        */
        void evt_active(vmp_bool active);
-
+       
        //! Close event
        void evt_close();
-
+       
        //! Free event
        void evt_free();
 };
