@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 07/01/2024
+ * Date last update: 28/03/2025
  */
 
 #include "event.h"
@@ -159,7 +159,7 @@ CroniterRef::~CroniterRef()
 
 vmp_uint CroniterRef::evt_croniter_next()
 {
-    return next_.next_cronizer(crontab_)-vmp::time::time_wrap();
+    return next_.next_cronizer(crontab_,seconds_)-vmp::time::time_wrap();
 }
 
 void croniter_evt(event::Cell *cell)
@@ -211,11 +211,12 @@ void CroniterUI::free_ref(event::Cell *cell)
     cevent->crontab_="";
     cevent->event_=0;
     cevent->badnext_=false;
+    cevent->seconds_=0;
     cevent->evt_timer_free();
     cref_.free(cevent);
 }
 
-event::Cell *CroniterUI::new_croniter(vmp::str evtname,vmp::str crontab,event::EVTCB event,event::EVTCB clevent,vmp_bool active)
+event::Cell *CroniterUI::new_croniter(vmp::str evtname,vmp::str crontab,event::EVTCB event,event::EVTCB clevent,vmp_bool active,vmp_uint seconds)
 {
     event::Cell *cell;
     CroniterRef *cevent=cref_.get();
@@ -224,6 +225,7 @@ event::Cell *CroniterUI::new_croniter(vmp::str evtname,vmp::str crontab,event::E
     {
         cevent->evtname_=evtname;
         cevent->crontab_=crontab;
+        cevent->seconds_=seconds;
         cevent->next_.set();
         cevent->evt_croniter_next();
         cell=cevent->evt_timer_new(this,0,croniter_evt,clevent);
