@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/01/2025
+   Date last update: 09/05/2025
 */
 
 #include "vmp.h"
@@ -57,6 +57,12 @@ const vmp_int status_resource_accessdenied=-15;/*!<User by jrp protocol for mess
 const vmp_int status_kill_notcomplete=-16;/*!<User by jrp protocol for message states 'kill incomplete operation'*/
 const vmp_int status_forward_denied=-17;/*!<User by jrp protocol for message states 'Forward Denied'*/
 const vmp_int status_request_overflow=-18;/*!<User by jrp protocol for message states 'Overflow request'*/
+const vmp_int status_resource_notfound=-19;/*!<User by jrp protocol for message states 'Resource Not Found'*/
+const vmp_int status_request_timeout=-20;/*!<User by jrp protocol for message states 'Request timeout'*/
+const vmp_int status_managed_timeout=-21;/*!<User by jrp protocol for message states 'Managed timeout'*/
+const vmp_int status_accesspeerdenied=-22;/*!<Used by the jrp protocol for message states 'Access Peer Denied'*/
+const vmp_int status_internal=-23;/*!<Used by the jrp protocol for message states 'Internal error'*/
+const vmp_int status_resource_killed=-24;/*!<User by jrp protocol for message states 'Resource Killed'*/
 
 const vmp_index min_permits=0;/*!<Minimum limit of JRP permits*/
 const vmp_index max_permits=255;/*!<Maximum limit of JRP permissions*/
