@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/01/2025
+   Date last update: 09/05/2025
 */
 
 #include "jrp.h"
@@ -65,6 +65,18 @@ vmp::str msg_status(vmp_int status)
             return "Forward Denied";
         case jrp::status_request_overflow:
             return "Overflow request";
+        case jrp::status_resource_notfound:
+            return "Resource Not Found";
+        case jrp::status_request_timeout:
+            return "Request Timeout";
+        case jrp::status_managed_timeout:
+            return "Managed Timeout";
+        case jrp::status_accesspeerdenied:
+            return "Access Peer Denied";
+        case jrp::status_internal:
+            return "Internal error";
+        case jrp::status_resource_killed:
+            return "Resource Killed";
         default:
             return "Undef error";
     }
