@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 05/12/2024
+   Date last update: 06/12/2024
 */
 
 #include "jrp.h"
@@ -385,7 +385,7 @@ void jrp_write_str(vmp::Buf *buf,vmp::str jrp,vmp::Buf *payload)
     buf->reset();
     buf->write_size(jrp.size(),4);
     buf->write_str(jrp);
-    if(payload != 0 && payload->size() != 0)
+    if((payload != 0) && (payload->size() != 0))
         buf->write_buf(payload);
     buf->index();
 }
