@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 20/03/2025
+   Date last update: 09/05/2025
 */
 
 #ifndef VAMPIRIA_JRP_MISC_H
@@ -25,12 +25,18 @@
 
 namespace vampiria { namespace jrp { namespace misc {
 
+//! Returns the full name of the data type jrp::misc(example jrp::misc::'jtype')
+/*!
+    @param jtype short name data type json
+    @return full name data type jrp::misc 
+*/
+vmp::str japi(vmp::str jtype);
+
 //!Common JRP Message Management Interface
 class JrpApi_I
 {
     private:
         vmp::vector<vmp::str> types_;/*!<List of managed types*/
-        vmp::thread::Mutex mutex_;
     protected:
         //!Used in subclasses to insert types to be managed
         /*!
@@ -38,6 +44,8 @@ class JrpApi_I
         */
         void addtype(vmp::str type);
     public:
+        vmp::thread::Mutex mutex_;/*!<Mutex object*/
+        
         //! A constructor
         JrpApi_I();
         
@@ -133,4 +141,6 @@ class JrpApi_I
 
 #include "misc/utils.h"
 #include "misc/status.h"
+#include "misc/onion.h"
+
 
