@@ -16,13 +16,20 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 20/03/2025
+   Date last update: 22/07/2025
 */
 
 #include "jrp.h"
 
 namespace vampiria { namespace jrp { namespace misc {
 
+vmp::str japi(vmp::str jtype)
+{
+    vmp::str ret;
+    vmp::unicode::str_write(&ret,"jrp::misc::%s",jtype.c_str());
+    return ret;
+}
+
 JrpApi_I::JrpApi_I()
 {
 }
@@ -39,15 +46,22 @@ void JrpApi_I::addtype(vmp::str type)
 
 vmp_bool JrpApi_I::management(jrp::JrpReq *jreq,vmp::Buf *payload)
 {
+    vmp_bool ret=false;
     mutex_.lock();
     if((jreq != 0) && vmp::invector<vmp::str>(jreq->jdata_type(),types_))
     {
-        management_impl(jreq,payload);
-        mutex_.unlock();
-        return true;
+        try
+        {
+            management_impl(jreq,payload);
+        }
+        catch(vmp::exception &x)
+        {
+            vmp::error("JrpApi_I::management() fatal '%s'",x.what());
+        }
+        ret=true;
     }
     mutex_.unlock();
-    return false;
+    return ret;
 }
 
 void JrpApi_I::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
@@ -56,15 +70,22 @@ void JrpApi_I::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
 
 vmp_bool JrpApi_I::management_response(jrp::JrpReq *jreq,json::JsonObj *jdata,vmp::Buf *payload)
 {
+    vmp_bool ret=false;
     mutex_.lock();
     if((jreq != 0) && vmp::invector<vmp::str>(jreq->jdata_type(),types_))
     {
-        management_response_impl(jreq,jdata,payload);
-        mutex_.unlock();
-        return true;
+        try
+        {
+            management_response_impl(jreq,jdata,payload);
+        }
+        catch(vmp::exception &x)
+        {
+            vmp::error("JrpApi_I::management_response() fatal '%s'",x.what());
+        }
+        ret=true;
     }
     mutex_.unlock();
-    return false;
+    return ret;
 }
 
 void JrpApi_I::management_response_impl(jrp::JrpReq *jreq,json::JsonObj *jdata,vmp::Buf *payload)
@@ -73,15 +94,22 @@ void JrpApi_I::management_response_impl(jrp::JrpReq *jreq,json::JsonObj *jdata,v
 
 vmp_bool JrpApi_I::management_push(jrp::JrpReq *jreq,json::JsonObj *jdata,vmp::Buf *payload)
 {
+    vmp_bool ret=false;
     mutex_.lock();
     if((jreq != 0) && vmp::invector<vmp::str>(jreq->jdata_type(),types_))
     {
-        management_push_impl(jreq,jdata,payload);
-        mutex_.unlock();
-        return true;
+        try
+        {
+            management_push_impl(jreq,jdata,payload);
+        }
+        catch(vmp::exception &x)
+        {
+            vmp::error("JrpApi_I::management_push() fatal '%s'",x.what());
+        }
+        ret=true;
     }
     mutex_.unlock();
-    return false;
+    return ret;
 }
 
 void JrpApi_I::management_push_impl(jrp::JrpReq *jreq,json::JsonObj *jdata,vmp::Buf *payload)
@@ -90,15 +118,22 @@ void JrpApi_I::management_push_impl(jrp::JrpReq *jreq,json::JsonObj *jdata,vmp::
 
 vmp_bool JrpApi_I::management_kill(jrp::JrpReq *jreq)
 {
+    vmp_bool ret=false;
     mutex_.lock();
     if((jreq != 0) && vmp::invector<vmp::str>(jreq->jdata_type(),types_))
     {
-        management_kill_impl(jreq);
-        mutex_.unlock();
-        return true;
+        try
+        {        
+            management_kill_impl(jreq);
+        }
+        catch(vmp::exception &x)
+        {
+            vmp::error("JrpApi_I::management_kill() fatal '%s'",x.what());
+        }
+        ret=true;
     }
     mutex_.unlock();
-    return false;
+    return ret;
 }
 
 void JrpApi_I::management_kill_impl(jrp::JrpReq *jreq)
@@ -107,15 +142,22 @@ void JrpApi_I::management_kill_impl(jrp::JrpReq *jreq)
 
 vmp_bool JrpApi_I::management_close(jrp::JrpReq *jreq)
 {
+    vmp_bool ret=false;
     mutex_.lock();
     if((jreq != 0) && vmp::invector<vmp::str>(jreq->jdata_type(),types_))
     {
-        management_close_impl(jreq);
-        mutex_.unlock();
-        return true;
+        try
+        {
+            management_close_impl(jreq);
+        }
+        catch(vmp::exception &x)
+        {
+            vmp::error("JrpApi_I::management_close() fatal '%s'",x.what());
+        }
+        ret=true;
     }
     mutex_.unlock();
-    return false;
+    return ret;
 }
 
 void JrpApi_I::management_close_impl(jrp::JrpReq *jreq)
