@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 27/12/2024
+   Date last update: 02/07/2025
 */
 
 #include "jrp.h"
@@ -91,12 +91,15 @@ void Status::cache()
     vmp::fs::chmod_wrap(filecache_,0600);
 }
 
-vmp_bool Status::islimit(vmp::str jkey,jrp::JrpReq *jreq)
+vmp_bool Status::islimit(vmp::vector<vmp::str> accepted,jrp::JrpReq *jreq)
 {
     vmp::vector<vmp_index> plist;
-    vmp_bool limits=limits_.search(jkey,&plist);
-    if(limits && !vmp::invector<vmp_index>(sessionpermits(jreq->cell()),plist))
-        return true;
+    for(vmp_index i=0;i<accepted.size();i++)
+    {
+        limits_.search(accepted[i],&plist);
+        if(!vmp::invector<vmp_index>(sessionpermits(jreq->cell()),plist))
+            return true;
+    }
     return false;
 }
 
@@ -104,11 +107,17 @@ void Status::broadcast(json::JsonObj *jdata,vmp::str jkey)
 {
     cache();
     vmp::vector<jrp::JrpReq *> data=jreqs_.all_data();
+    vmp::vector<vmp::str> limits=limits_.all_keys(),accepted;
+    for(vmp_index i=0;i<limits.size();i++)
+    {
+        if(vmp::unicode::str_regex_matching(jkey,limits[i]))
+            accepted.push_back(limits[i]);
+    }
     for(vmp_index i=0;i<data.size();i++)
     {    
         try
         {
-            if(!islimit(jkey,data[i]))
+            if(!islimit(accepted,data[i]))
                 data[i]->response(jdata);
         }
         catch(vmp::exception &x)
@@ -306,11 +315,18 @@ void Status::request_open(jrp::JrpReq *jreq)
         json::JsonObj array,obj;
         list.root()->add_object_array("",&array);
         vmp_index j=0;
+        vmp::vector<vmp::str> limits=limits_.all_keys(),accepted;
         for(vmp_index i=0;i<keys.size();i++)
         {
-            jtable_.search(keys[i],&obj);
-            if(!islimit(keys[i],jreq))
+            accepted.clear();
+            for(vmp_index j=0;j<limits.size();j++)
             {
+                if(vmp::unicode::str_regex_matching(keys[i],limits[j]))
+                    accepted.push_back(limits[j]);
+            }
+            if(!islimit(accepted,jreq))
+            {
+                jtable_.search(keys[i],&obj);
                 json::japi_status_update(tmp.json_new(),keys[i],&obj);
                 array.push_array_obj_ex(tmp.root());
                 if(j == 9)
@@ -377,6 +393,84 @@ void Status::management_kill_impl(jrp::JrpReq *jreq)
     request_close(jreq->key(),jrp::status_killed);
 }
 
+StatusGet::StatusGet()
+{
+    reset();
+}
+
+StatusGet::~StatusGet()
+{
+    reset();
+}
+
+void StatusGet::reset()
+{
+    key_="";
+    data_.reset();
+}
+
+vmp::str StatusGet::key()
+{
+    return key_;
+}
+
+json::JsonObj *StatusGet::data()
+{
+    return &data_;
+}
+
+vmp_bool StatusGet::management_update(vmp::str keyregex,jrp::JrpReq *jreq,json::JsonObj *jdata)
+{
+   reset();
+   if((jreq != 0) && (jdata != 0) && (jreq->jdata_type() == json::japi("status")))
+   {
+       try
+       {
+           json::JData jd;
+           jd.set(jdata);
+           if(jd.jtype() == json::japi("statusupdate"))
+           {
+               key_=jd.get_text("key");
+               if(vmp::unicode::str_regex_matching(key_,keyregex))
+               {
+                   jd.get_subtype("data",&data_);
+                   return true;
+               }
+           }
+           reset();
+       }
+       catch(vmp::exception &x)
+       {
+           reset();
+       }
+   }
+   return false;
+}
+
+vmp_bool StatusGet::management_cancel(vmp::str keyregex,jrp::JrpReq *jreq,json::JsonObj *jdata)
+{
+   reset();
+   if((jreq != 0) && (jdata != 0) && (jreq->jdata_type() == json::japi("status")))
+   {
+       try
+       {
+           json::JData jd;
+           jd.set(jdata);
+           if(jd.jtype() == json::japi("statuscancel"))
+           {
+               key_=jd.get_text("key");
+               if(vmp::unicode::str_regex_matching(key_,keyregex))
+                   return true;
+           }
+           reset();
+       }
+       catch(vmp::exception &x)
+       {
+           reset();
+       }
+   }
+   return false;
+}
+
 }}}
 
-
