@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 27/12/2024
+   Date last update: 02/07/2025
 */
 
 #ifndef VAMPIRIA_JRP_MISC_STATUS_H
@@ -34,7 +34,7 @@ class Status:public jrp::misc::JrpApi_I
         json::Json root_;/*!<State memory*/
         json::JTable jtable_;/*!<Internal usage*/
         vmp::Table<vmp::str,jrp::JrpReq *> jreqs_;/*!<Json request table to send status update to*/
-        vmp::Table<vmp::str,vmp::vector<vmp_index> >limits_;/*!<Restrict the permissions for keys to send to users*/
+        vmp::Table<vmp::str,vmp::vector<vmp_index> >limits_;/*!<Restrict the permissions for keys(regular expression) to send to users*/
         vmp::str dirpath_;/*!<Directory used to store status files*/
         vmp::str filecache_;/*!<Internal usage*/
         
@@ -42,7 +42,7 @@ class Status:public jrp::misc::JrpApi_I
         void cache();
         
         //!Internal usage
-        vmp_bool islimit(vmp::str jtype,jrp::JrpReq *jreq);
+        vmp_bool islimit(vmp::vector<vmp::str> accepted,jrp::JrpReq *jreq);
         
         //!Internal usage
         void broadcast(json::JsonObj *jdata,vmp::str jkey);
@@ -69,7 +69,7 @@ class Status:public jrp::misc::JrpApi_I
         //!Restrict the permissions for keys to send to users
         /*!
             @ref limits_
-            @param jkey jdata key
+            @param jkey regular expression of the jdata key
             @param permits accepted permission range
         */
         void set_limit(vmp::str jkey,vmp::str permits);
@@ -147,6 +147,54 @@ class Status:public jrp::misc::JrpApi_I
         void management_kill_impl(jrp::JrpReq *jreq);
 };
 
+//!Manages data sent in response to a status request json::japi("statusupdate") and json::japi("statuscancel")
+class StatusGet
+{
+    private:
+        vmp::str key_;/*!<Key of the updated  or cancel object*/
+        json::JsonObj data_;/*!Value of the updated object*/
+    public:
+        //!A constructor
+        StatusGet();
+        
+        //!A destructor
+        ~StatusGet();
+        
+        //! Reset data
+        void reset();
+        
+        //! Returns key of the updated  or cancel object
+        /*!
+            @sa key_
+            @return key data
+        */
+        vmp::str key();
+        
+        //! The value of the updated object
+        /*!
+            @sa data_
+            @return the value of the updated object
+        */
+        json::JsonObj *data();
+        
+        //! Check if the input request and type json::japi("statusupdate") and the key matching the keyregex in input.If the verification is ok the data are stored
+        /*!
+            @param keyregex regular expression to verify the key
+            @param jdata json data in input
+            @return true if the verification is ok,otherwise false
+        */
+        vmp_bool management_update(vmp::str keyregex,jrp::JrpReq *jreq,json::JsonObj *jdata);
+        
+        //! Check if the input request and type json::japi("statuscancel") and the key matching the keyregex in input.If the verification is ok the data are stored
+        /*!
+            @param keyregex regular expression to verify the key
+            @param jreq jrp request associated
+            @param jdata json data in input
+            @return true if the verification is ok,otherwise false
+        */
+        vmp_bool management_cancel(vmp::str keyregex,jrp::JrpReq *jreq,json::JsonObj *jdata);
+};
+
 }}}
 
 #endif
