@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 20/03/2025
+   Date last update: 30/06/2025
 */
 
 #include "jrp.h"
@@ -25,7 +25,7 @@ namespace vampiria { namespace jrp { namespace misc {
 
 Passwd::Passwd(crypto::Ctx_Peer_Web *ctx):jrp::misc::JrpApi_I()
 {
-    vmp::except_check_pointer((void *) ctx,"jrp::misc::Passwd::(ctx=Null)");
+    vmp::except_check_pointer((void *) ctx,"jrp::misc::Passwd(ctx=Null)");
     addtype(json::japi("passwd"));
     ctx_=ctx;
 }
@@ -70,7 +70,7 @@ void Passwd::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
 
 User::User(crypto::Ctx_Peer_Web *ctx):jrp::misc::JrpApi_I()
 {
-    vmp::except_check_pointer((void *) ctx,"jrp::misc::Passwd::(ctx=Null)");
+    vmp::except_check_pointer((void *) ctx,"jrp::misc::User(ctx=Null)");
     addtype(json::japi("userlist"));
     addtype(json::japi("useradd"));
     addtype(json::japi("usermod"));
@@ -216,7 +216,7 @@ void User::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
 
 Peer::Peer(crypto::Ctx_Peer *ctx):jrp::misc::JrpApi_I()
 {
-    vmp::except_check_pointer((void *) ctx,"jrp::misc::Peer::(ctx=Null)");
+    vmp::except_check_pointer((void *) ctx,"jrp::misc::Peer(ctx=Null)");
     ctx_=ctx;
     addtype(json::japi("peerlist"));
     addtype(json::japi("peeradd"));
@@ -376,7 +376,7 @@ void ConnectStatus::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
                         cell=jrpui_->connect_search(id);
                         if(cell == 0)
                             vmp::except("id field '%s' not found",id.c_str());
-                        cell->close("jrp::ConnectStatus");
+                        crypto::ssl_shutdown(cell,"jrp::ConnectStatus");
                     }
                 }
                 else if(type == "wss")
@@ -386,7 +386,7 @@ void ConnectStatus::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
                         cell=wssjrpui_->connect_search(id);
                         if(cell == 0)
                             vmp::except("id field '%s' not found",id.c_str());
-                        cell->close("jrp::ConnectStatus");
+                        crypto::ssl_shutdown(cell,"jrp::ConnectStatus");
                     }
                 }
                 else
@@ -431,5 +431,122 @@ void ConnectStatus::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
     }
 }
 
+Logs::Logs()
+{
+    addtype(json::japi("logs"));
+    addtype(json::japi("logread"));
+}
+
+Logs::~Logs()
+{
+}
+
+void Logs::set_logdir(vmp::str key,vmp::str dirpath)
+{
+    dirs_.update(key,&dirpath);
+}
+
+void Logs::register_common(jrp::JrpCommon *common,vmp::str permits)
+{
+    if(common !=0)
+    {
+        common->add_reqdata(json::japi("logs"),{},{json::japi("logfiles")},permits);
+        common->add_reqdata(json::japi("logread"),{},{json::japi("logview")},permits);
+    }
+}
+
+void Logs::management_impl(jrp::JrpReq *jreq,vmp::Buf *payload)
+{
+    if(jreq != 0)
+    {
+        vmp::str jtype=jreq->jdata_type();
+        json::JData jdata;
+        vmp_int ret=jrp::status_ok;
+        vmp::str retvalue="";
+        json::Json json;
+        if(jtype == json::japi("logs"))
+        {
+            vmp::vector<vmp::str> keys=dirs_.all_keys(),files,listen;
+            vmp::str dirpath,preamble,file;
+            for(vmp_index i=0;i<keys.size();i++)
+            {
+                dirs_.search(keys[i],&dirpath);
+                try
+                {
+                    listen=vmp::sort<vmp::str>(vmp::fs::listendir(dirpath));
+                    if(keys[i] == "")
+                        preamble="";
+                    else
+                        vmp::unicode::str_write(&preamble,"%s/",keys[i].c_str());
+                    for(vmp_index j=0;j<listen.size();j++)
+                    {
+                        file=vmp::fs::union_path(dirpath,listen[j]);
+                        if(vmp::fs::isrfile(file) && vmp::unicode::str_regex_matching(listen[j],".*\\.log(\\.[0-9]*)?"))
+                        {
+                            vmp::unicode::str_write(&file,"%s%s",preamble.c_str(),listen[j].c_str());
+                            files.push_back(file);   
+                        }
+                    }
+                }
+                catch(vmp::exception &x)
+                {
+                }
+            }
+            json::japi_logfiles(json.root(),files);
+            jreq->response(json.root());
+        }
+        else
+        {
+            try
+            {
+                jdata.set(jreq->jdata_root());
+                vmp::str logname=jdata.get_text("logname");
+                vmp::str key,dirpath="",file="";
+                vmp::vector<vmp::str> split=vmp::unicode::str_split(logname,"/");
+                if(split.size() == 1)
+                {
+                    if(split[0] == "" || !dirs_.search("",&dirpath))
+                        ret=jrp::status_resource_notfound;
+                    else
+                        file=split[0];   
+                }
+                else if(split.size() == 2)
+                {
+                    if(!dirs_.search(split[0],&dirpath))
+                        ret=jrp::status_resource_notfound;
+                    else
+                        file=split[1];
+                }
+                else
+                    ret=jrp::status_resource_notfound;
+                if(dirpath != "")
+                {
+                    vmp::unicode::str_write(&file,"%s/%s",dirpath.c_str(),file.c_str());
+                    if(vmp::fs::isrfile(file))
+                    {
+                        file=vmp::input_file_s(file);
+                        vmp_size s=file.size();
+                        if(s > 1000000)
+                        {
+                            file=vmp::unicode::str_sub(file,s-1000000,1000000);
+                            vmp::unicode::str_write(&file,"(... truncated)\n%s",file.c_str());
+                        }
+                        json::japi_logview(json.root(),logname,file);
+                        jreq->response(json.root());
+                    }
+                    else
+                        ret=jrp::status_resource_notfound;
+                }
+            }
+            catch(vmp::exception &x)
+            {
+                retvalue=x.what();
+                ret=jrp::status_input_bad;
+            }
+        }
+        jreq->close(ret,retvalue);
+    }
+}
+
 }}}
 
