@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/01/2025
+   Date last update: 21/03/2025
 */
 
 #ifndef VAMPIRIA_JRP_MISC_UTILS_H
@@ -116,6 +116,32 @@ class ConnectStatus:public jrp::misc::JrpApi_I
         void management_impl(jrp::JrpReq *jreq,vmp::Buf *payload);
 };
 
+//! Class used for for managing the display of system logs
+class Logs:public jrp::misc::JrpApi_I
+{
+    private:
+        vmp::Table<vmp::str,vmp::str> dirs_;/*!<Directory log files(key,dir)*/
+    public:
+        //! A constructor
+        Logs();
+        
+        //! A destructor
+        ~Logs();
+        
+        //!Set a directory to read the logs. A log file will be seen remotely as key/filename.log, if key=="" will be seen as filename.log
+        /*!
+            @param key key log directory
+            @param dirpath directory that contains log files
+        */
+        void set_logdir(vmp::str key,vmp::str dirpath);
+        
+        //! virtual function
+        void register_common(jrp::JrpCommon *common,vmp::str permits="*");
+        
+        //! virtual function
+        void management_impl(jrp::JrpReq *jreq,vmp::Buf *payload);
+};
+
 }}}
 
 #endif
