@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta net::Address::
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 20/01/2024
+ * Date last update: 08/04/2025
  */
 
 #include "net.h"
@@ -40,7 +40,6 @@ vmp_bool is_ipv4_raw(vmp::str ip)
             {
                 break;
             }        
- 
         }
         if(i == 4)
             return true;
@@ -48,25 +47,15 @@ vmp_bool is_ipv4_raw(vmp::str ip)
     return false;
 }
 
-vmp::vector<vmp::str> ipv4_expand(vmp::str subnet,vmp_uint mask)
+vmp::vector<vmp_byte> ipv4_subnet_common(vmp::str ipv4,vmp_uint mask)
 {
-    vmp::vector<vmp::str> ret;
-    if(!net::is_ipv4_raw(subnet))
-        vmp::except("net::ipv4_expand(subnet=%s) input bad value",subnet.c_str());
-    if(mask > 32)
-        vmp::except("net::ipv4_expand(mask=%u) input bad value",mask);
-    vmp_byte snet[4];
-    vmp_byte shost[4];
-    vmp_uint tmp,tmp2,bmask;
     net::Address addr;
-    addr.set(subnet);
-    vmp::str sret;
+    vmp_uint tmp,tmp2,bmask;
+    vmp::vector<vmp_byte> snet;
+    addr.set(ipv4);
     struct sockaddr_in *saddr=(struct sockaddr_in *) addr.addr();
     tmp=(saddr->sin_addr.s_addr);
-    snet[0]=(vmp_byte)(tmp & 0xFF);
-    snet[1]=(vmp_byte)((tmp >> 8) & 0xFF);
-    snet[2]=(vmp_byte)((tmp >> 16) & 0xFF);
-    snet[3]=(vmp_byte)((tmp >> 24) & 0xFF);
+    snet={(vmp_byte)(tmp & 0xFF),(vmp_byte)((tmp >> 8) & 0xFF),(vmp_byte)((tmp >> 16) & 0xFF),(vmp_byte)((tmp >> 24) & 0xFF)};
     tmp=mask;
     for(vmp_index i=0;i<4;i++)
     {
@@ -87,6 +76,32 @@ vmp::vector<vmp::str> ipv4_expand(vmp::str subnet,vmp_uint mask)
         else
             tmp-=8;
     }
+    return snet;
+}
+
+vmp::str ipv4_subnet(vmp::str ipv4,vmp_uint mask)
+{
+    vmp::str ret;
+    vmp::vector<vmp_byte> snet; 
+    if(!net::is_ipv4_raw(ipv4))
+        vmp::except("net::ipv4_subnet(ipv4=%s) input bad value",ipv4.c_str());
+    if(mask > 32)
+        vmp::except("net::ipv4_subnet(mask=%u) input bad value",mask);
+    snet=ipv4_subnet_common(ipv4,mask);
+    vmp::unicode::str_write(&ret,"%u.%u.%u.%u",snet[0],snet[1],snet[2],snet[3]);
+    return ret;
+}
+
+vmp::vector<vmp::str> ipv4_expand(vmp::str net,vmp_uint mask)
+{
+    vmp::str sret;
+    vmp::vector<vmp::str> ret;
+    vmp::vector<vmp_byte> snet,shost; 
+    if(!net::is_ipv4_raw(net))
+        vmp::except("net::ipv4_expand(subnet=%s) input bad value",net.c_str());
+    if(mask > 32)
+        vmp::except("net::ipv4_expand(mask=%u) input bad value",mask);
+    snet=ipv4_subnet_common(net,mask);
     for(vmp_index i=0;i<= (vmp_index)(vmp::math::pow_wrap(2,32-mask)-1);i++)
     {
         shost[0]=(vmp_byte)(((i >> 24) & 0xFF) | snet[0]);
@@ -99,6 +114,21 @@ vmp::vector<vmp::str> ipv4_expand(vmp::str subnet,vmp_uint mask)
     return ret;
 }
 
+vmp_bool ipv4_to_net(vmp::str ipv4,vmp::str net,vmp_uint mask)
+{
+    vmp::str ip,subnet;
+    try
+    {
+        ip=ipv4_subnet(ipv4,mask);
+        subnet=ipv4_subnet(net,mask);
+    }
+    catch(vmp::exception &x)
+    {
+        return false;
+    }
+    return (ip == subnet);
+}
+
 vmp_bool is_ipv6_raw_frag(vmp::str ip,vmp_size *size)
 {
     vmp::vector<vmp::str> split=vmp::unicode::str_split(ip,":");	
@@ -140,6 +170,101 @@ vmp_bool is_ipv6_raw(vmp::str ip)
     return false;    
 }
 
+vmp::vector<vmp_byte> ipv6_subnet_common(vmp::str ipv6,vmp_uint mask)
+{
+    net::Address addr;
+    vmp_uint tmp,tmp2,bmask;
+    vmp::vector<vmp_byte> snet;
+    addr.set(ipv6);
+    struct sockaddr_in6 *saddr=(struct sockaddr_in6 *) addr.addr();
+    for(vmp_index i=0;i<16;i++)
+        snet.push_back((vmp_byte)(saddr->sin6_addr.s6_addr[i]));
+    tmp=mask;
+    for(vmp_index i=0;i<16;i++)
+    {
+        if(tmp == 0)
+            snet[i]=0x00;
+        else if(tmp < 8)
+        {
+            tmp2=7;
+            bmask=0;
+            while(tmp > 0)
+            {
+                bmask+= (vmp_uint) vmp::math::pow_wrap(2,tmp2);
+                tmp--;
+                tmp2--;
+            }
+            snet[i]=snet[i] & bmask;
+        }
+        else
+            tmp-=8;
+    }
+    return snet;
+}
+
+vmp::str ipv6_subnet(vmp::str ipv6,vmp_uint mask)
+{
+    vmp::str ret;
+    vmp::vector<vmp_byte> snet; 
+    if(!net::is_ipv6_raw(ipv6))
+        vmp::except("net::ipv6_subnet(ipv6=%s) input bad value",ipv6.c_str());
+    if(mask > 32)
+        vmp::except("net::ipv6_subnet(mask=%u) input bad value",mask);
+    snet=ipv6_subnet_common(ipv6,mask);
+    vmp::unicode::str_write(&ret,"%02X%02X:%02X%02X:%02X%02X:%02X%02X:%02X%02X:%02X%02X:%02X%02X:%02X%02X",snet[0],snet[1],snet[2],snet[3],snet[4],snet[5],snet[6],snet[7]);
+    return ret;
+}
+
+vmp_bool ipv6_to_net(vmp::str ipv6,vmp::str net,vmp_uint mask)
+{
+    vmp::str ip,subnet;
+    try
+    {
+        ip=ipv6_subnet(ipv6,mask);
+        subnet=ipv6_subnet(net,mask);
+    }
+    catch(vmp::exception &x)
+    {
+        return false;
+    }
+    return (ip == subnet);
+}
+
+vmp::str ipv6_addr_contracted(vmp::str ipv6)
+{
+    vmp::str ret="";
+    vmp_uint contracted=99;
+    vmp_byte b;
+    net::Address addr;
+    addr.set(ipv6);
+    struct sockaddr_in6 *saddr=(struct sockaddr_in6 *) addr.addr();
+    for(vmp_index i=15;i>=0;i--)
+    {
+        b=(vmp_byte)(saddr->sin6_addr.s6_addr[i]);
+        if(b == 0x00)
+        {
+            if(contracted != 100)
+                contracted=i;    
+        }
+        else
+        {
+            if((contracted != 100) && (contracted == i+1))
+            {
+                vmp::unicode::str_write(&ret,"%02X::%s",b,ret.c_str());
+                contracted=100;
+            }
+            else
+            {
+                if(i == 15)
+                    vmp::unicode::str_write(&ret,"%02X");
+                else
+                    vmp::unicode::str_write(&ret,"%02X:%s",b,ret.c_str());
+            }
+        }
+    }
+    return ret;
+}
+
 vmp_bool is_ip_raw(vmp::str ip)
 {
     if(is_ipv4_raw(ip) || is_ipv6_raw(ip))
