@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 09/01/2024
+ * Date last update: 08/04/2025
  */
 
 #ifndef VAMPIRIA_NET_ADDRESS_H
@@ -34,13 +34,29 @@ typedef struct sockaddr Sockaddr;/*!< struct sockaddr type(see linux doc)*/
 */
 vmp_bool is_ipv4_raw(vmp::str ip);
 
+//!Find the subnet of an ip
+/*!
+    @param ipv4 ipv4 address
+    @param mask network mask(0-32)
+    @return subnet network
+*/
+vmp::str ipv4_subnet(vmp::str ipv4,vmp_uint mask);
+
 //! It takes an ipv4 network in subnet mask format and returns the list of IPs associated with the network
 /*!
-    @param subnet subnet ipv4
+    @param net net ipv4
     @param mask network mask(0-32)
     @return ipv4 address list
 */
-vmp::vector<vmp::str> ipv4_expand(vmp::str subnet,vmp_uint mask);
+vmp::vector<vmp::str> ipv4_expand(vmp::str net,vmp_uint mask);
+
+//!Verify that the ip address is in the subnetwork
+/*!
+    @param ipv4 ipv4 address
+    @param net net ipv4
+    @param mask network mask(0-32)
+*/
+vmp_bool ipv4_to_net(vmp::str ipv4,vmp::str net,vmp_uint mask);
 
 //!Check if the input string is an ipv6 address
 /*!
@@ -49,6 +65,29 @@ vmp::vector<vmp::str> ipv4_expand(vmp::str subnet,vmp_uint mask);
 */
 vmp_bool is_ipv6_raw(vmp::str ip);
 
+//!Find the subnet of an ip
+/*!
+    @param ipv4 ipv4 address
+    @param mask network mask(0-128)
+    @return subnet network
+*/
+vmp::str ipv6_subnet(vmp::str ipv6,vmp_uint mask);
+
+//!Verify that the ip address is in the subnetwork
+/*!
+    @param ipv6 ipv6 address
+    @param net net ipv6
+    @param mask network mask(0-128)
+*/
+vmp_bool ipv6_to_net(vmp::str ipv6,vmp::str net,vmp_uint mask);
+
+//! Returns the contracted form of an IPv6 address
+/*!
+    @param ipv6 ipv6 address
+    @return ipv6 contracted form   
+*/
+vmp::str ipv6_addr_contracted(vmp::str ipv6);
+
 //!Check if the input string is an ip address
 /*!
     @param ip input string
