@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 29/10/2024
+ * Date last update: 18/07/2025
 */
  
 #include "net.h"
@@ -91,7 +91,13 @@ void socks4_writeaddress(vmp::Buf *out,net::Address *address)
     else if(address->is_ipv6())
         vmp::except_s("address='ipv6 not supported from sock4'");
     else
-        vmp::except_s("address='bad input address'");
+    {
+        vmp::str host=address->host();
+        net::Address tmp;
+        tmp.set("0.0.0.255");
+        net::ip_to_buf(&tmp,out);
+        out->write_str(host);
+    }
 }
 
 void socks4_request(vmp::Buf *out,vmp_byte cd,net::Address *address,vmp::str userid)
@@ -181,7 +187,7 @@ vmp_byte socks4_reply_get(vmp::Buf *input,net::Address *address)
     return cd;
 }
 
-vmp_bool socks5_writeaddress(vmp::Buf *out,net::Address *address)
+void socks5_writeaddress(vmp::Buf *out,net::Address *address)
 {
     if(address->is_onlyhost())
     {
@@ -218,10 +224,14 @@ vmp_bool socks5_writeaddress(vmp::Buf *out,net::Address *address)
         net::ip_to_buf(address,out);
     }
     else
-        return false;
+    {
+        vmp::str host=address->host();
+        out->write_byte(net::socks5_atype_domain);
+        out->write_size(host.size(),1);
+        out->write_str(host);
+    }
     vmp_uint service=vmp::unicode::str_todigit_range(address->service(),0,65535);
     out->write_size(service,2);
-    return true;
 }
 
 void socks5_readaddress(vmp::Buf *input,net::Address *address)
@@ -292,8 +302,7 @@ void socks5_request(vmp::Buf *out,vmp_byte cd,net::Address *address)
     out->write_byte(0x05);
     out->write_byte(cd);
     out->write_byte(0x00);
-    if(!net::socks5_writeaddress(out,address))
-        vmp::except_s("net::socks5_request(address='bad input address')");
+    net::socks5_writeaddress(out,address);
 }
 
 vmp_byte socks5_request_get(vmp::Buf *input,net::Address *address)
@@ -322,8 +331,7 @@ void socks5_reply(vmp::Buf *out,vmp_byte cd,net::Address *address)
     out->write_byte(0x05);
     out->write_byte(cd);
     out->write_byte(0x00);
-    if(!net::socks5_writeaddress(out,address))
-        vmp::except_s("net::socks5_reply(address='bad input address')");
+    net::socks5_writeaddress(out,address);
 }
 
 vmp_byte socks5_reply_get(vmp::Buf *input,net::Address *address)
@@ -357,8 +365,7 @@ void socks5_udp(vmp::Buf *out,vmp_byte frag,net::Address *address,vmp::Buf *data
     if(frag > 255)
         vmp::except("net::socks5_udp(frag=%u) bad value",frag);
     out->write_byte(frag);
-    if(!net::socks5_writeaddress(out,address))
-        vmp::except_s("net::socks5_udp(address='bad input address')");
+    net::socks5_writeaddress(out,address);
     out->write_buf(data);
 }
 
