@@ -133,7 +133,7 @@ class Packet
         //!Returns the data in string format associated with the field
         /*!
             @param field input field
-            @return associated data(except error)
+            @return associated data or except in case of failure
         */
         virtual vmp::str get(vmp::str field);
 
