@@ -168,7 +168,7 @@ class PyObj
 	//!Get attribute name from ref
 	/*!
 	    @param name attribute name
-	    @return attribute object(except error)
+	    @return attribute object or except in case of failure
 	*/
         PyObj get_attr(vmp::str name);	
 };
