@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 23/01/2020
+   Date last update: 30/05/2024
  */
 
 #ifndef VAMPIRIA_PYLIB_ARG_FROM_PYTHON_H
@@ -70,6 +70,12 @@ vmp_char arg_from_python<vmp_char>(pylib::Objref *obj);
 template<>
 vmp_uchar arg_from_python<vmp_uchar>(pylib::Objref *obj);
 
+template<>
+vmp_int16 arg_from_python<vmp_int16>(pylib::Objref *obj);
+
+template<>
+vmp_uint16 arg_from_python<vmp_uint16>(pylib::Objref *obj);
+
 template<>
 vmp_int arg_from_python<vmp_int>(pylib::Objref *obj);
 
@@ -77,10 +83,10 @@ template<>
 vmp_uint arg_from_python<vmp_uint>(pylib::Objref *obj);
 
 template<>
-vmp_int16 arg_from_python<vmp_int16>(pylib::Objref *obj);
+vmp_int64 arg_from_python<vmp_int64>(pylib::Objref *obj);
 
 template<>
-vmp_uint16 arg_from_python<vmp_uint16>(pylib::Objref *obj);
+vmp_uint64 arg_from_python<vmp_uint64>(pylib::Objref *obj);
 
 template<>
 vmp_real arg_from_python<vmp_real>(pylib::Objref *obj);
