@@ -298,6 +298,7 @@ void pyerr_occurred()
     vmp::str error;
     if(occurred)
     {
+        vmp::utils::syslog_s(vmp::utils::LOG_DEBUG,"pylib::pyerr_occurred()");
         pylib::Objref *ptype,*pvalue,*ptraceback;
         PyErr_Fetch(&ptype,&pvalue, &ptraceback);
         PyErr_NormalizeException(&ptype,&pvalue,&ptraceback);
@@ -317,7 +318,9 @@ void pyerr_occurred()
         pylib::decref(ptype);
         pylib::decref(pvalue);
         pylib::decref(ptraceback);
+        vmp::utils::syslog(vmp::utils::LOG_DEBUG,"pylib::pyerr_occurred() '%s'",error.c_str());
         pylib::pyerr_clear();
+        vmp::utils::syslog(vmp::utils::LOG_DEBUG,"pylib::pyerr_occurred() clear data",error.c_str());
         vmp::except_s(error);
      }
 }
