@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/05/2014
+   Date last update: 30/05/2025
  */
 
 #include "vmp.h"
@@ -48,7 +48,7 @@ void memcpy_wrap(void *dest, const void *src,vmp_size n)
     memcpy(dest,src,n);
 }
 
-const vmp::str strerror_wrap(vmp_int err)
+vmp::str strerror_wrap(vmp_int err)
 {
     return strerror(err);
 }
