@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 29/10/2024
+   Date last update: 30/05/2025
  */
 
 #include <string>
@@ -89,12 +89,12 @@ void memcpy_wrap(void *dest, const void *src,vmp_size n);
 */
 void strncpy_wrap(vmp_char *dest, const vmp_char *src,vmp_size n);
 
-//! Creates a string from error value(Macro varying number of arguments list va_list,va_start(ap,fmt) and va_end(ap) in stdarg.h)
+//! Creates a string from linux error value
 /*!
      @param err error value
-     @return The resulting string 
+     @return the resulting string 
 */
-const vmp::str strerror_wrap(vmp_int err);
+vmp::str strerror_wrap(vmp_int err);
 
 //! vector
 template<typename DATA>
