@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/06/2024
+   Date last update: 28/05/2025
  */
 
 #include "vmp.h"
@@ -370,6 +370,20 @@ vmp_size Buf::write_xstr(vmp::str value)
     return write_vector(bytes);
 }
 
+vmp_size Buf::write_xstr_hm(vmp::str value,vmp::str delimiter)
+{
+    vmp::vector<vmp_byte> bytes;
+    try
+    {
+        bytes=vmp::unicode::xstr_tobytes_hm(value,delimiter);
+    }
+    catch(vmp::exception &x)
+    {
+        vmp::except("write xstr %s",x.what());
+    }
+    return write_vector(bytes);
+}
+
 vmp::str Buf::read_xstr(vmp_size size)
 {
     vmp::vector<vmp_byte> bytes;
