@@ -15,7 +15,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/06/2024
+   Date last update: 28/05/2025
  */
 
 #ifndef VAMPIRIA_VMP_BUF_H
@@ -210,7 +210,15 @@ class Buf
             @return the number of bytes written in the buffer
         */                  
         vmp_size write_xstr(vmp::str value);
-                
+        
+        //! Write string of exadecimal in human mode values in the buffer to the index_ position and increments the index_ value
+        /*!
+            @param value input string
+            @param delimiter byte delimiter
+            @return the number of bytes written in the buffer
+        */                  
+        vmp_size write_xstr_hm(vmp::str value,vmp::str delimiter);
+              
         //! Read string of exadecimal values from the buffer in the index_ position and increments the index_ value.
         /*!
             @param size size to read
