@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 15/03/2025
+   Date last update: 02/04/2025
  */
  
 #ifndef VAMPIRIA_VMP_LIB_TYPES_H
@@ -81,6 +81,14 @@ vmp_bool istype_wrap(vmp_int c,vmp::str type);
 */
 vmp_char *strtok_r_wrap(vmp_char *str, const vmp_char *delim,vmp_char **saveptr);
 
+//! Compares the two strings s1 and s2
+/*!
+    @param s1 input string
+    @param s2 input string
+    @return 0 if the s1 and s2 are equal,a negative value if s1 is less than s2,a positive value if s1 is greater than s2
+*/
+vmp_int strcmp_wrap(const vmp_char *s1,const vmp_char *s2);
+
 //! Performs a byte-by-byte comparison of the strings s1 and s2, ignoring the case of the characters
 /*!
     @param s1 input string
@@ -88,7 +96,7 @@ vmp_char *strtok_r_wrap(vmp_char *str, const vmp_char *delim,vmp_char **saveptr)
     @param n  size strings
     @return an integer less than, equal to, or greater than zero if s1 
 */
-vmp_int strncasecmp_wrap(const vmp_char *s1, const vmp_char *s2, vmp_size n);
+vmp_int strncasecmp_wrap(const vmp_char *s1, const vmp_char *s2,vmp_size n);
 
 //!Returns a pointer to the first occurrence of the character c in the string s
 /*!
