@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 27/12/2024
+   Date last update: 21/03/2025
  */
 
 #include <map>
@@ -86,7 +86,7 @@ class Table
                  vmp::except_s("Table insert error key already");
         }
 
-        //! Insert a value in the table. If the key already set data with old value otherwise set data pointer to 0. 
+        //! Insert a value in the table. If the key already set data with old value . 
         /*!
              @param key key table
              @param pdata pointer data value
@@ -101,12 +101,9 @@ class Table
                  data_.insert(std::pair<KEY,DATA>(key,*pdata));
                  return false;
              }
-             else
-             {
-                 DATA *tmp2=pdata;
-                 cancel(key,pdata);
-                 data_.insert(std::pair<KEY,DATA>(key,(*tmp2)));
-             }
+             DATA *tmp2=pdata;
+             cancel(key,pdata);
+             data_.insert(std::pair<KEY,DATA>(key,(*tmp2)));
              return true;
         }
         
