@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 13/01/2023
+   Date last update: 23/01/2023
  */
 
 #include "vmp.h"
@@ -156,7 +156,8 @@ void Thread::th_except(vmp::str except)
 
 Mutex::Mutex()
 {
-    pthread_mutex_init(&mutex_,0);
+    if(pthread_mutex_init(&mutex_,0) != 0)
+        vmp::except_errno();
 }
         
 Mutex::~Mutex()
@@ -166,12 +167,37 @@ Mutex::~Mutex()
         
 void Mutex::lock()
 {
-    pthread_mutex_lock(&mutex_);
+    
+    if(pthread_mutex_lock(&mutex_) != 0)
+        vmp::except_errno();
 }
         
 void Mutex::unlock()
 {
-    pthread_mutex_unlock(&mutex_);
+    if(pthread_mutex_unlock(&mutex_) != 0)
+        vmp::except_errno();
+}
+
+vmp_bool Mutex::forced_unlock()
+{
+    vmp_int ret=pthread_mutex_trylock(&mutex_);
+    if(ret == -1) 
+    {
+        if(errno==EBUSY)
+        {
+            unlock();
+            return true;
+        }   
+        vmp::except_errno();
+    }
+    unlock();
+    return false;
+}
+
+void Mutex::recovery_lock(vmp_bool status)
+{
+    if(status)
+        lock();
 }
 
 Blocking::Blocking()
