@@ -531,7 +531,7 @@ vmp_uint Localtime::set_from_year_day(vmp_int year_v,vmp_uint nday,vmp_int hour_
     return time_;
 }
 
-vmp_uint Localtime::next_cronizer(vmp::str crontab)
+vmp_uint Localtime::next_cronizer(vmp::str crontab,vmp_uint seconds)
 {
     vmp::vector<vmp::str> exprs=vmp::unicode::str_split(vmp::unicode::str_tolower(crontab)," ");
     try
@@ -569,6 +569,8 @@ vmp_uint Localtime::next_cronizer(vmp::str crontab)
         vmp::error(x.what());
         vmp::except("vmp::time::Localtime::next_cronizer(crontab=%s) bad value",crontab.c_str());
     }
+    if(seconds != 0)
+        set(time_+seconds);
     return time_;
 }
 
