@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 11/11/2024
+   Date last update: 28/03/2025
  */
 
 #include <time.h>
@@ -179,10 +179,11 @@ class Localtime
         //! Calculates the time of the next event from the time stored in the object and the input crontab. Stores the new time in the object
         /*!
             @param crontab string in crontab mode (minute hour day_of_the_month month day_of_the_week[0-6 sunday-saturday]) 
+            @param seconds number of seconds to be added to the calculated time
             @ref time_
             @return new time value or except in case of failure
         */
-        vmp_uint next_cronizer(vmp::str crontab);
+        vmp_uint next_cronizer(vmp::str crontab,vmp_uint seconds=0);
         
         //! Returns setting time
         /*!
