@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 02/12/2024
+   Date last update: 06/07/2025
  */
 
 #include "vmp.h"
@@ -69,9 +69,10 @@ vmp::str str_toupper(vmp::str str)
     return ret;   
 }
 
-vmp::vector<vmp::str> str_split(vmp::str str,vmp::str delimiter)
+vmp::vector<vmp::str> str_split(vmp::str str,vmp::str delimiter,vmp_bool emptystr)
 {
     vmp::vector<vmp::str> ret;
+    vmp_size s=str.size();
     vmp::str tmp="";         
     vmp_index i=0;
     if(delimiter.size() == 0)
@@ -85,20 +86,20 @@ vmp::vector<vmp::str> str_split(vmp::str str,vmp::str delimiter)
     }
     else
     {        
-        while(i<str.size())
+        while(i<s)
         {
             if(str.substr(i,delimiter.size()) == delimiter)
             {
-                if(tmp.size() != 0)
+                if((tmp.size() != 0) || emptystr)
                     ret.push_back(tmp);
                 tmp="";                        
                 i += delimiter.size();
-            }    
+            }
             else
                 tmp += str[i++];
         }
     }
-    if(tmp.size() != 0)
+    if(tmp.size() != 0 || ((str.substr(i-delimiter.size(),delimiter.size()) == delimiter) && emptystr))
         ret.push_back(tmp);
     return ret;
 }
@@ -109,7 +110,7 @@ vmp::str str_join(vmp::vector<vmp::str> list,vmp::str token)
     for(vmp_index i=0;i<s+1;i++)
     {
         ret += list[i];
-        if(i != s)                
+        if(i != s)    
            ret += token;
     }
     return ret;
@@ -253,6 +254,28 @@ vmp::vector<vmp_byte> xstr_tobytes(vmp::str xstr)
     return ret;
 }
 
+vmp::vector<vmp_byte> xstr_tobytes_hm(vmp::str xstr,vmp::str delimiter)
+{
+    vmp::vector<vmp::str> split=vmp::unicode::str_split(xstr,delimiter);
+    vmp::vector<vmp_byte> bytes,b;
+    for(vmp_index i=0;i<split.size();i++)
+    {
+        try
+        {
+            b=vmp::unicode::xstr_tobytes(split[i]);
+            if(b.size() == 1)
+                bytes.push_back(b[0]);
+            else
+                vmp::except_s("");
+        }
+        catch(vmp::exception &x)
+        {
+            vmp::except("String '%s' is not hexadecimal with delimiter '%s'",xstr.c_str(),delimiter.c_str());
+        }
+    }
+    return bytes;
+}
+
 vmp::str bytes_toxstr(vmp::vector<vmp_byte> bytes)
 {
     vmp::str ret="";
@@ -339,7 +362,7 @@ vmp_bool str_findsub(vmp::str str,vmp::str sub)
 
 vmp::str str_replace(vmp::str text,vmp::str find,vmp::str sub)
 {
-    vmp::vector<vmp::str> vtext=vmp::unicode::str_split(text,find);
+    vmp::vector<vmp::str> vtext=vmp::unicode::str_split(text,find,true);
     return vmp::unicode::str_join(vtext,sub);
 }
 
