@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/05/2024
+   Date last update: 28/05/2025
  */
 
 #include <regex>
@@ -77,9 +77,10 @@ vmp::str str_toupper(vmp::str str);
 /*!
      @param str input string
      @param delimiter token value
+     @param emptystr if true inserts the empty strings in the results
      @return split strings
 */
-vmp::vector<vmp::str> str_split(vmp::str str,vmp::str delimiter);
+vmp::vector<vmp::str> str_split(vmp::str str,vmp::str delimiter,vmp_bool emptystr=false);
 
 //! Creates a string concatenate strings in list, inserting the token between the strings,if delimiter="" return charatters list
 /*!
@@ -168,6 +169,13 @@ vmp_real str_toreal_range(vmp::str dstr,vmp_real min,vmp_real max);
 */
 vmp::vector<vmp_byte> xstr_tobytes(vmp::str xstr);
 
+//! Converts a string of exadecimal values in human mode in the byte vector (2 characters 0-F 1 byte)
+/*!
+     @param xstr string input
+     @return byte vector or except in case of failure.
+*/
+vmp::vector<vmp_byte> xstr_tobytes_hm(vmp::str xstr,vmp::str delimiter);
+
 //! Converts a bytes vector to a string of hexadecimal values
 /*!
      @param bytes byte vector input
@@ -175,7 +183,7 @@ vmp::vector<vmp_byte> xstr_tobytes(vmp::str xstr);
 */
 vmp::str bytes_toxstr(vmp::vector<vmp_byte> bytes);
 
-//! Converts a bytes vector to a string of hexadecimal values in human mode(the reverse function does not work)
+//! Converts a bytes vector to a string of hexadecimal values in human mode
 /*!
      @param bytes byte vector input
      @param delimiter byte delimiter
