@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 27/02/2025
+   Date last update: 31/03/2025
  */
 
 #include "vmp.h"
@@ -35,8 +35,9 @@ Logger::~Logger()
 
 void Logger::reset()
 {
-    logname_="";    
+    logname_="";  
     loglevel_=vmp::utils::LOG_NO;
+    user_="";
 }
 
 vmp::str Logger::logname()
@@ -49,14 +50,19 @@ vmp_byte Logger::loglevel()
     return loglevel_;
 }
 
-void Logger::set(vmp::str filepath,vmp_byte facility,vmp_bool newfile)
+void Logger::set(vmp::str filepath,vmp_byte facility,vmp_bool newfile,vmp::str user)
 {
     if(loglevel_ > vmp::utils::LOG_ERR)
         vmp::except_s("Invalid facility value");
     logname_=filepath;
     loglevel_=facility;
+    user_=user;
     if(loglevel_ != vmp::utils::LOG_NO)
+    {    
         vmp::output_file_s(logname_,newfile,"");
+        vmp::fs::chown_user(logname_,user_);
+        vmp::fs::chmod_wrap(logname_,0600);
+    }
 }
 
 void Logger::write_s(vmp_byte facility,vmp::str value)
@@ -93,12 +99,22 @@ void Logger::rotate(vmp_index n)
             vmp::unicode::str_write(&src,"%s.%u",logname_.c_str(),i);
             vmp::unicode::str_write(&dst,"%s.%u",logname_.c_str(),i+1);
             if(vmp::fs::isfile(src))
+            {
                 vmp::copy_file(src,dst);
+                vmp::fs::chown_user(dst,user_);
+                vmp::fs::chmod_wrap(logname_,0600);
+            }
         }
         vmp::unicode::str_write(&dst,"%s.1",logname_.c_str());
         if(vmp::fs::isfile(logname_))
+        {
             vmp::copy_file(logname_,dst);
+            vmp::fs::chown_user(dst,user_);
+            vmp::fs::chmod_wrap(dst,0600);
+        }
         vmp::output_file_s(logname_,true,"");
+        vmp::fs::chown_user(logname_,user_);
+        vmp::fs::chmod_wrap(logname_,0600);
     }
 }
 
