@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 20/03/2025
+   Date last update: 25/03/2025
  */
 /**
  *Virtual class interface for websocket login (see Vmp_Cmp_Main)<br>
@@ -890,6 +890,86 @@ class Vmp_Cmp_ConnectStatus extends Vmp_Cmp_Div
       vmp_wrap_alert(`${voper} error '${req.close_msg_}'`) 
   }
 };
+/**
+  *Component for managing logs
+**/
+class Vmp_Cmp_Logs extends Vmp_Cmp_Div
+{
+  /**constructor*/
+  constructor()
+  {
+    super();
+    let filelist=vmp_cmp_select();
+    filelist.style.setProperty("display","inline-block");
+    filelist.style.setProperty("min-width","100px");
+    this.appendChild(filelist);
+    this.register_cmp("filelist",filelist);
+    let update=vmp_cmp_button("update filelist","update");
+    update.style.setProperty("display","inline-block");
+    update.addEventListener("click",this.oper.bind(this));
+    this.appendChild(update);
+    let view=vmp_cmp_button("view file","view");
+    view.addEventListener("click",this.oper.bind(this));
+    view.style.setProperty("display","inline-block");
+    this.appendChild(view);
+    let textview=vmp_cmp_textview("99%","400px",true);
+    this.register_cmp("textview",textview);
+    this.appendChild(textview);
+  }
+  oper(event)
+  {
+    let rid=event.currentTarget.bid();
+    if(rid == "update")
+    {
+      let jdata=japi_logs();
+      window.main_.request(this,jdata);
+      window.main_.waiting("Logs list",10000,Vmp_WebSocketCode.Protocol,"Logs list close timeout");
+    }
+    else
+    {
+      let value=this.search_cmp("filelist").get_value();
+      if(value == "")
+        vmp_wrap_alert("update filelist");
+      else
+      {
+        let jdata=japi_logread(value);
+        window.main_.request(this,jdata);
+        window.main_.waiting("Logs list",10000,Vmp_WebSocketCode.Protocol,"Logs list close timeout");
+      }
+    }
+  }
+  /**virtual function*/
+  req_recv(req,jdata,payload)
+  {
+    if(jdata.jtype() == vmp_japi_type("logfiles"))
+    {
+        let files=jdata.get_args("files");
+        let filelist=this.search_cmp("filelist");
+        filelist.childRemoveAll();
+        for(let f of files)filelist.add_option(f,f);
+    }
+    else if (jdata.jtype() == vmp_japi_type("logview"))
+    {
+        let logname=jdata.get_text("logname");
+        let view=jdata.get_text("view");
+        this.search_cmp("textview").set_text(logname,view);
+    }
+  }
+  /**virtual function*/
+  req_close(req)
+  {
+    window.main_.main();
+    let voper;
+    if(req.type_ === vmp_japi_type("logs"))
+      voper="Logs list";
+    else
+      voper="Log read";
+    if(req.close_status_ === Vmp_Jrp_StatusCode.ok)
+      vmp_wrap_alert(`${voper} ok`);
+    else
+      vmp_wrap_alert(`${voper} error '${req.close_msg_}'`) 
+  }
+};
 /**
   *The default component JRP and session message management class(see Vmp_Cmp_Main)
   *@extends Vmp_Jrp_Manager_I
@@ -943,6 +1023,7 @@ class Vmp_Cmp_Manager extends Vmp_Jrp_Manager_I
     this.register_cmp("users",vmp_wrap_createElement("vmp-user",'div'));
     this.register_cmp("peers",vmp_wrap_createElement("vmp-peer",'div'));
     this.register_cmp("connectstatus",vmp_wrap_createElement("vmp-connectstatus",'div'));
+    this.register_cmp("logs",vmp_wrap_createElement("vmp-logs",'div'));
     let body=vmp_cmp_menu();
     this.register_cmp("body",body);
     this.appendChild(body);
@@ -995,6 +1076,8 @@ class Vmp_Cmp_Manager extends Vmp_Jrp_Manager_I
       body.add_section("Peers",this.search_cmp("peers"));
     if (vmp_japi_type("connectlist") in this.reqdata_)
       body.add_section("Connection",this.search_cmp("connectstatus"));
+    if (vmp_japi_type("logs") in this.reqdata_)
+      body.add_section("Logs",this.search_cmp("logs"));
   }
   /**Virtual function called on request*/
   update_request(req)
@@ -1026,6 +1109,7 @@ try
   vmp_wrap_define("vmp-user",Vmp_Cmp_User,'div');
   vmp_wrap_define("vmp-peer",Vmp_Cmp_Peer,'div');
   vmp_wrap_define("vmp-connectstatus",Vmp_Cmp_ConnectStatus,'div');
+  vmp_wrap_define("vmp-logs",Vmp_Cmp_Logs,'div');
   vmp_wrap_define("vmp-manager",Vmp_Cmp_Manager,'div');
 }
 catch(error)
