@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 26/02/2025
+   Date last update: 27/05/2025
  */
 /**
   *decorator who transforms a tag into a component
@@ -184,14 +184,12 @@ function vmp_component(element)
   /**
     *@name vmp_component#parents
     *@function
-    *Return parent tag
     *@return {Tag} parents tag o null in case of root tag
   */
   element.prototype.parent=function(){return vmp_tag_parents(this);}
   /**
     *@name vmp_component#parents
     *@function
-    *Return index children tag
     *@param children index
     *@return {Tag} the children referred to the index
 */
@@ -324,14 +322,86 @@ function vmp_component(element)
   */
   element.prototype.msg_recv=function(jdata,buf){}
   /**
-    *Virtual function that receives a response from an associated request
+    *Function that receives a response from an associated request
     *@name vmp_component#req_recv
     *@param req request associated
     *@param jdata {Vmp_JData} json data
     *@param payload {Vmp_Buf} buffer data
     *@function
   */
-  element.prototype.req_recv=function(req,jdata,payload){}
+  element.prototype.req_recv=function(req,jdata,payload)
+  {
+    let jtype=jdata.jtype();
+    if(jtype === vmp_japi_type("statusupdate"))
+    {
+      let key=jdata.get_text("key");
+      let data=jdata.get_subtype("data");
+      if(this.status_update(req,key,data))
+        return;
+    }
+    else if(jtype === vmp_japi_type("statuscancel"))
+    {
+      let key=jdata.get_text("key");
+      if(this.status_cancel(req,key))
+        return;
+    }
+    this.req_recv_impl(req,jdata,payload);
+  }
+  /**
+    *Virtual function that receives a response from an associated request(Call from req_recv())
+    *@name vmp_component#req_recv_impl
+    *@param req request associated
+    *@param jdata {Vmp_JData} json data
+    *@param payload {Vmp_Buf} buffer data
+    *@function
+  */
+  element.prototype.req_recv_impl=function(req,jdata,payload){}
+  /**
+    *Function called when an vmp_japi_type("statusupdate") JData is received
+    *@name vmp_component#status_update
+    *@param req request associated
+    *@param key status item key
+    *@param jdata data item
+    *@return true if the data has been processed,otherwise false
+  */  
+  element.prototype.status_update=function(req,key,jdata)
+  {
+    if(this.status_update_impl(req,key,jdata)) return true;
+    for(const [k,value] of this.register_)
+      if(value.status_update(req,key,jdata)) return true; 
+    return false;
+  }
+  /**
+    *Virtual function call from status_update when an vmp_japi_type("statusupdate") JData is received
+    *@name vmp_component#status_update_impl
+    *@param req request associated
+    *@param key status item key
+    *@param jdata data item
+    *@return true if the data has been processed,otherwise false
+  */  
+  element.prototype.status_update_impl=function(req,key,jdata){return false;}
+  /**
+    *Function called when an vmp_japi_type("statuscancel") JData is received
+    *@name vmp_component#status_cancel
+    *@param req request associated
+    *@param key status item key
+    *@return true if the data has been processed,otherwise false
+  */  
+  element.prototype.status_cancel=function(req,key)
+  {
+    if(this.status_cancel_impl(req,key)) return true;
+    for(const [k,value] of this.register_) 
+      if(value.status_cancel(req,key)) return true; 
+    return false;
+  }
+  /**
+    *Virtual function call from status_cancel when an vmp_japi_type("statusupdate") JData is received
+    *@name vmp_component#status_cancel_impl
+    *@param req request associated
+    *@param key status item key
+    *@return true if the data has been processed,otherwise false
+  */  
+  element.prototype.status_cancel_impl=function(req,key){return false;}
   /**
     *Virtual function that close request
     *@name vmp_component#req_close
@@ -528,7 +598,8 @@ class Vmp_Cmp_Input extends vmp_component(HTMLInputElement)
   init(size,placeholder,default_v="")
   {
     this.setAttribute("size",size);
-    this.setAttribute("placeholder",`Enter ${placeholder}`);
+    if(placeholder != "")
+      this.setAttribute("placeholder",`Enter ${placeholder}`);
     this.set_value(default_v);
   }
   /**virtual function*/
@@ -602,9 +673,9 @@ class Vmp_Cmp_Button_Base extends vmp_component(HTMLButtonElement)
     this.setAttribute("data-id",id);
   }
   /**virtual function*/
-  enable_impl(){vmp_tag_enable(this);}
+  enable_impl(){vmp_tag_enable(this);this.style.setProperty("cursor",vmp_rootvar("--cursor-pointer"));}
   /**virtual function*/
-  disable_impl(){vmp_tag_disable(this);}
+  disable_impl(){vmp_tag_disable(this);this.style.setProperty("cursor",vmp_rootvar("--cursor-unpointer"));}
   /**Returns button id*/
   bid(){return this.getAttribute("data-id");}
 };
@@ -645,19 +716,27 @@ class Vmp_Cmp_Select extends vmp_component(HTMLSelectElement)
   /**A constructor*/
   constructor(){super();vmp_component_init(this);}  
   /**
-    *Initialize Component
-    *@param values {ArrayObject} Objects option {value:"value options",text:"text value"}  
+    *Set option data
+    *@param values {ArrayObject} Objects option {value:"value options",text:"text value"}
   */
-  init(...values)
+  set_values(...values)
+  {
+    this.childRemoveAll();
+    this.reset_impl();
+    for(let v of values) this.add_option(v.value,v.text);
+  }
+  /**
+    *Adds an option to the select
+    *@param value {String} value options
+    *@param text {String} text value
+  */
+  add_option(value,text)
   {
     let option;
-    for(let v of values)
-    {
-      option=vmp_wrap_createElement("option");
-      option.setAttribute("value",v.value);
-      option.innerHTML=v.text;
-      this.appendChild(option);
-    }
+    option=vmp_wrap_createElement("option");
+    option.setAttribute("value",value);
+    option.innerHTML=text;
+    this.appendChild(option);
   }
   /**virtual function*/
   reset_impl(){this.set_value(0);}
@@ -688,13 +767,15 @@ catch(error)
 /**
   *Create div component
   *@param id component id
-  *@param parent component parent  
+  *@param parent component parent
+  *@return {Vmp_Cmp_Div} component div
 */
 function vmp_cmp_div(){return vmp_wrap_createElement("vmp-div",'div');}
 /**
   *Create table component
   *@param id component id
-  *@param parent component parent 
+  *@param parent component parent
+  *@return {Vmp_Cmp_Table} component table 
 */
 function vmp_cmp_table(){return vmp_wrap_createElement("vmp-table",'table');}
 /**
@@ -702,7 +783,7 @@ function vmp_cmp_table(){return vmp_wrap_createElement("vmp-table",'table');}
   *@param size {Size} visual size
   *@param placeholder {String} containing a hint to the user of what can be entered in the control
   *@param default_v {String} default value
-  *@return {Tag} component input
+  *@return {Vmp_Cmp_Input} component input
 */
 function vmp_cmp_input(size,placeholder,default_v="")
 {
@@ -713,7 +794,7 @@ function vmp_cmp_input(size,placeholder,default_v="")
 /**
   *Create Component CheckBox
   *@param value {String} checkbox value  
-  *@return {Tag} component checkbox
+  *@return {Vmp_Cmp_CheckBox} component checkbox
 */
 function vmp_cmp_checkbox(value,sdefault=false)
 {
@@ -723,10 +804,10 @@ function vmp_cmp_checkbox(value,sdefault=false)
   return ret;
 }
 /**
-  *Create Component button base,Styles not implemented
+  *Create Component button base,styles not implemented
   *@param label {String} label
   *@param bid {String} button id
-  *@return {Tag} component base button
+  *@return {Vmp_Cmp_Button_Base} component base button
 */
 function vmp_cmp_bbutton(label,bid="")
 {
@@ -738,7 +819,7 @@ function vmp_cmp_bbutton(label,bid="")
   *Create Component button text
   *@param label {String} label
   *@param bid {String} button id
-  *@return {Tag} component button
+  *@return {Vmp_Cmp_Button} component button
 */
 function vmp_cmp_button(label,bid="")
 {
@@ -751,7 +832,7 @@ function vmp_cmp_button(label,bid="")
   *@param img {String} img path
   *@param alt {String} image alt attribute
   *@param bid {String} button id
-  *@return {Tag} component password
+  *@return {Vmp_Cmp_Button} button with image
 */
 function vmp_cmp_button_img(img,alt,bid="")
 {
@@ -763,7 +844,7 @@ function vmp_cmp_button_img(img,alt,bid="")
   *Create Component img
   *@param src {String} target img
   *@param alt {String} alt attribute
-  *@return {Tag} component img
+  *@return {Vmp_Cmp_Img} component img
 */
 function vmp_cmp_img(src,alt)
 {
@@ -774,12 +855,12 @@ function vmp_cmp_img(src,alt)
 /**
   *Create Component select
   *@param values {Object} Objects option {value:"value options",text:"text value"}  
-  *@return {Tag} component img
+  *@return {Vmp_Cmp_Select} component select
 */
 function vmp_cmp_select(...values)
 {
   let ret=vmp_wrap_createElement("vmp-select",'select');
-  ret.init(...values);
+  ret.set_values(...values);
   return ret;
 }
 /**Password form + view button*/
@@ -1037,7 +1118,7 @@ class Vmp_Cmp_List extends Vmp_Cmp_Table
   }
   /**
     *init new object type list
-    *@param cols {Object} Objects with fields {name:"column name",width:"column width"(default notr assigned),order:Can the data be sorted?(default false)}
+    *@param cols {Object} Objects with fields {name:"column name",width:"column width"(default not assigned),order:Can the data be sorted?(default false)}
   */
   init(...cols)
   {
@@ -1267,7 +1348,7 @@ class Vmp_Cmp_List extends Vmp_Cmp_Table
 /**Component to insert tags with title and value, or single objects*/
 class Vmp_Cmp_Info extends Vmp_Cmp_Table
 {
-  /**constructor**/
+  /**A constructor**/
   constructor()
   {
     super();
@@ -1372,7 +1453,7 @@ class Vmp_Cmp_Info extends Vmp_Cmp_Table
 /**Component used for project presentation*/
 class Vmp_Cmp_Top extends Vmp_Cmp_Table
 {
-  /**constructor**/
+  /**A constructor**/
   constructor()
   {
     super();
@@ -1416,6 +1497,72 @@ class Vmp_Cmp_Top extends Vmp_Cmp_Table
   */
   change_info(info){vmp_tag_childReplace(this.info_,info,0);}
 };
+/**A Component to display texts*/
+class Vmp_Cmp_TextView extends Vmp_Cmp_Div
+{
+  /**A constructor*/
+  constructor()
+  {
+    super();
+  }
+  /**
+    *Init component text view
+    *@param width {String} width view
+    *@param height {String} height view
+    *@param closetext {Boolean} The Close Text button is present
+  */
+  init(width,height,closetext=false)
+  {
+    this.up=vmp_cmp_div();
+    this.up.style.setProperty("text-align","center");
+    this.up.style.setProperty("border-bottom",`${vmp_rootvar("--border-width")} ${vmp_rootvar("--border-style")} ${vmp_rootvar("--border-color")}`);
+    let title=vmp_cmp_div();
+    title.style.setProperty("display","inline-block");
+    this.up.appendChild(title);
+    if(closetext)
+    {
+      let close=vmp_cmp_button_img(Vmp_Img.close,"Close File"); 
+      close.addEventListener("click",this.close.bind(this));
+      close.style.setProperty("margin-left","20px");
+      this.register_cmp("close",close);
+      close.style.setProperty("display","inline-block");
+      this.up.appendChild(close);
+    }
+    this.register_cmp("title",title);
+    this.style.setProperty("border",`${vmp_rootvar("--border-width")} ${vmp_rootvar("--border-style")} ${vmp_rootvar("--border-color")}`);
+    this.style.setProperty("width",width);
+    this.style.setProperty("height","100%");
+    this.appendChild(this.up);
+    let body=vmp_cmp_div();
+    body.style.setProperty("white-space","pre");
+    body.style.setProperty("overflow-y","scroll");
+    body.style.setProperty("overflow-x","scroll");
+    body.style.setProperty("height",height);
+    this.register_cmp("body",body);
+    this.appendChild(body);
+    this.close();
+  }
+  /**
+    *Insert text in view
+    *@param title {String} text title
+    *@param body {String} text body
+  */
+  set_text(title,body)
+  {
+    this.search_cmp("title").innerHTML=title;
+    let close=this.search_cmp("close");
+    if(close != undefined)close.enable();
+    this.search_cmp("body").innerHTML=body;
+  }
+  /**Internal usage*/
+  close(event)
+  {
+    this.search_cmp("title").innerHTML='-';
+    let close=this.search_cmp("close");
+    if(close != undefined)close.disable();
+    this.search_cmp("body").innerHTML="";
+  }
+};
 try
 {
   vmp_wrap_define("vmp-password",Vmp_Cmp_Password,'div');
@@ -1423,6 +1570,7 @@ try
   vmp_wrap_define("vmp-list",Vmp_Cmp_List,'table');
   vmp_wrap_define("vmp-info",Vmp_Cmp_Info,'table');
   vmp_wrap_define("vmp-top",Vmp_Cmp_Top,'table');
+  vmp_wrap_define("vmp-textview",Vmp_Cmp_TextView,'div');
 }
 catch(error)
 {
@@ -1433,7 +1581,7 @@ catch(error)
   *@param size {Size} visual size
   *@param placeholder {String} containing a hint to the user of what can be entered in the control
   *@param default_v {String} default value
-  *@return {Tag} component password
+  *@return {Vmp_Cmp_Password} component password
 */
 function vmp_cmp_password(size,placeholder,default_v="")
 {
@@ -1443,13 +1591,13 @@ function vmp_cmp_password(size,placeholder,default_v="")
 }
 /**
   *Build menu component
-  *@return {Tag} Menu component
+  *@return {Vmp_Cmp_Menu} Menu component
 */
 function vmp_cmp_menu(){return vmp_wrap_createElement("vmp-menu",'div');}
 /**
   *Build new component list
   *@param cols {Object} Objects with fields {name:"column name",width:"column width"(default not assigned),order:Can the data be sorted?(default false)}
-  *@return {Tag} Menu component
+  *@return {Vmp_Cmp_List} Menu component
 */
 function vmp_cmp_list(...cols)
 {
@@ -1459,7 +1607,7 @@ function vmp_cmp_list(...cols)
 }
 /**
   *Build new component info
-  *@return {Tag} component info
+  *@return {Vmp_Cmp_Info} component info
 */
 function vmp_cmp_info(){return vmp_wrap_createElement("vmp-info",'table');}
 /**
@@ -1467,7 +1615,7 @@ function vmp_cmp_info(){return vmp_wrap_createElement("vmp-info",'table');}
   *@param img {String} Image paths
   *@param title {String} Project title
   *@param info {Tag} Info tag
-  *@return {Tag} component top
+  *@return {Vmp_Cmp_Top} component top
 */
 function vmp_cmp_top(img,title,info)
 {
@@ -1475,3 +1623,16 @@ function vmp_cmp_top(img,title,info)
   ret.init(img,title,info);
   return ret;
 }
+/**
+  *Create text view component
+  *@param width {String} width view
+  *@param height {String} height view
+  *@param closetext {Boolean} The Close Text button is present
+  *@return {Vmp_Cmp_TextView} component textview
+*/
+function vmp_cmp_textview(width,height,closetext=false)
+{
+  let ret=vmp_wrap_createElement("vmp-textview",'div');
+  ret.init(width,height,closetext);
+  return ret;
+}
