@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/01/2025
+   Date last update: 22/07/2025
  */
 /**Used to work with JData lists*/
 class Vmp_JList
@@ -52,7 +52,7 @@ class Vmp_JList
     {
       if(!vmp_isarray(list)) vmp_except("");
       let jdata=new Vmp_JData();
-      for(l of list)
+      for(let l of list)
       {
         jdata.set_data(l);
         if((jtype != "") && (jdata.jtype() != jtype))
@@ -808,9 +808,15 @@ class Vmp_JData
 /**
   *Returns the full name of the data type json(example json::'jtype')
   *@param jtype short name data type json
-  *@return {string} full name data type json 
+  *@return {String} full name data type json 
 */
 function vmp_japi_type(jtype){return `json::${jtype}`;}
+/**
+  *Returns the full name of the data type jrp::misc(example jrp::misc'jtype')
+  *@param jtype short name data type jrp::misc
+  *@return {String} full name data type jrp::misc
+*/
+function vmp_japi_type_jrp_misc(jtype){return `jrp::misc::${jtype}`;}
 /**
   *Returns json type list [subtype] or []
   *@param jtype json type in list("" list not typed)
@@ -1214,7 +1220,7 @@ function japi_connectlist()
   *}
   *</pre>
   *@param id {String} connect id   (read data jdata.get_text("id"))
-  *@param id {String} connect type (read data jdata.get_text("type"))
+  *@param type {String} connect type (read data jdata.get_text("type"))
   *@return {Vmp_JData} json data
 */
 function vmp_japi_connectclose(id,type)
@@ -1225,3 +1231,43 @@ function vmp_japi_connectclose(id,type)
   ret.set_text("type",type);
   return ret;  
 }
+/**
+  *Create a json data vmp_japi_type("logs") used to request the list of log files
+  *<pre>
+  *{ 
+  *  jtype: vmp_japi_type("logs"),
+  *  jbody: 
+  *  {
+  *  }
+  *}
+  *</pre>
+  *@return {Vmp_JData} json data
+*/
+function japi_logs()
+{
+  let ret=new Vmp_JData();
+  ret.new_data(vmp_japi_type("logs"));
+  return ret;    
+}
+/** 
+  *Create a json data vmp_japi_type("logread") used to request the contents of a log file
+  *<pre>
+  *{ 
+  *  jtype: vmp_japi_type("logread"),
+  *  jbody: 
+  *  {
+  *    logname:'log name',
+  *  }
+  *}
+  *</pre>
+  *@param logname {String} the required file (read data jdata.get_text("logname"))  
+  *@return {Vmp_JData} json data
+*/
+function japi_logread(logname)
+{
+  let ret=new Vmp_JData();
+  ret.new_data(vmp_japi_type("logread"));
+  ret.set_text("logname",logname);
+  return ret; 
+}
+
