@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 24/12/2024
+   Date last update: 09/05/2025
  */
  /**Json request protocol status code*/
 const Vmp_Jrp_StatusCode={
@@ -37,6 +37,14 @@ const Vmp_Jrp_StatusCode={
   resource_busy:-14,/*!<User by jrp protocol for message states 'Resource busy'*/
   resource_accessdenied:-15,/*!<User by jrp protocol for message states 'Resource Access Denied'*/
   kill_notcomplete:-16,/*!<User by jrp protocol for message states 'kill incomplete operation'*/
+  status_forward_denied:-17,/*!<User by jrp protocol for message states 'Forward Denied'*/
+  status_request_overflow:-18,/*!<User by jrp protocol for message states 'Overflow request'*/
+  status_resource_notfound:-19,/*!<User by jrp protocol for message states 'Resource Not Found'*/
+  status_request_timeout:-20,/*!<User by jrp protocol for message states 'Request timeout'*/
+  status_managed_timeout:-21,/*!<User by jrp protocol for message states 'Managed timeout'*/
+  status_accesspeerdenied:-22,/*!<Used by the jrp protocol for message states 'Access Peer Denied'*/
+  status_internal:-23,/*!<Used by the jrp protocol for message states 'Internal error'*/
+  status_resource_killed:-24,/*!<User by jrp protocol for message states 'Resource Killed'*/
   reason(code)
   {
     switch(code)
@@ -58,6 +66,14 @@ const Vmp_Jrp_StatusCode={
       case this.resource_busy:return "Resource Busy";
       case this.resource_accessdenied:return "Resource Access Denied";
       case this.kill_notcomplete:return "Kill incomplete operation";
+      case this.status_forward_denied:return "Forward Denied";
+      case this.status_request_overflow:return "Overflow request";
+      case this.status_resource_notfound:return "Resource Not Found";
+      case this.status_request_timeout:return "Request Timeout";
+      case this.status_managed_timeout:return "Managed Timeout";
+      case this.status_accesspeerdenied:return "Access Peer Denied";
+      case this.status_internal:return "Internal error";
+      case this.status_resource_killed:return "Resource Killed";
       default:return "Undef error";
     }
   }
