@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/01/2025
+   Date last update: 30/03/2025
  */
 
 #include "main.h"
@@ -129,7 +129,7 @@ vmp::str Vampiria::get_root()
     {
         vmp::str tmp;
         vmp::unicode::str_write(&tmp,"%u/",pid_);
-        tmp=vmp::env::vampiria_cache(tmp);    
+        tmp=vmp::env::vampiria_cache(tmp);
         vmp::fs::mkdir_wrap(tmp,0700);
         root_=tmp;
     }
@@ -144,8 +144,18 @@ Process *Vampiria::add_process(xml::Tag *ptag,vmp::str id,vmp_bool init,process:
     if(init && (proot_ != 0))
         ptag->parser_error("Duplicate init process prev in line %u",proot_->ptag_->get_line());
     vmp::str rootdir=get_root();
-    vmp::unicode::str_write(&rootdir,"%s%s/",get_root().c_str(),id.c_str());
+    if(user != "")
+        vmp::fs::chmod_wrap(rootdir,0755);
+    vmp::unicode::str_write(&rootdir,"%s%s/",rootdir.c_str(),id.c_str());
     vmp::fs::mkdir_wrap(rootdir,0700);
+    try
+    {
+        vmp::fs::chown_user(rootdir,user);
+    }
+    catch(vmp::exception &x)
+    {
+        ptag->parser_error("Change permits directory error='%s',parameter user='%s' in line %u",x.what(),user.c_str(),ptag->get_line());
+    }
     process=new Process(id);
     process->envp_=(*envp_);
     process->ptag_=ptag;
@@ -157,7 +167,7 @@ Process *Vampiria::add_process(xml::Tag *ptag,vmp::str id,vmp_bool init,process:
     process->user_=user;
     process->set(rootdir,run_process,output_process,error_process,end_process);
     process_.insert(id,process);
-    vmp::debug("Set Process id '%s' Root Directory '%s'",id.c_str(),rootdir.c_str());
+    vmp::debug("Set Process id '%s' Root Directory '%s' user='%s'",id.c_str(),rootdir.c_str(),user.c_str());
     return process;
 }
 
